using System.Runtime.Serialization;
using System.Collections.Generic;

namespace Ato.EN.IntegrationServices.CodeGenerationIDS2022
{
    /// <summary>
    /// IDS
    /// </summary>
    [DataContract(Name = "IDS", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class IDS
    {

        [DataMember(EmitDefaultValue = false, Order = 1)]
        public RP RP { get; set; }
    }

    /// <summary>
    /// Details of foreign country dealings
    /// </summary>
    [CollectionDataContract(Name = "ForeignDealingsCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="ForeignDealings" )]
    public class ForeignDealingsCollection: List<ForeignDealings> {}

    /// <summary>
    /// Details of foreign country dealings
    /// </summary>
    [DataContract(Name = "ForeignDealings", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ForeignDealings
    {

        /// <summary>
        /// Foreign country dealings - Activity code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryActivityC { get; set; }

        /// <summary>
        /// Foreign country dealings - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Foreign country dealings - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? RevenueTotalA { get; set; }
    }

    /// <summary>
    /// Dealings with foreign country
    /// </summary>
    [CollectionDataContract(Name = "ForeignCountryCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="ForeignCountry" )]
    public class ForeignCountryCollection: List<ForeignCountry> {}

    /// <summary>
    /// Dealings with foreign country
    /// </summary>
    [DataContract(Name = "ForeignCountry", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ForeignCountry
    {

        /// <summary>
        /// International dealings - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public ForeignDealingsCollection ForeignDealingsCollection { get; set; }

        /// <summary>
        /// Foreign country dealings - All other expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? ExpenseOtherA { get; set; }

        /// <summary>
        /// Foreign country dealings - All other revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? RevenueOtherA { get; set; }
    }

    /// <summary>
    /// Details of specified country dealings
    /// </summary>
    [CollectionDataContract(Name = "SpecifiedDealingsCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="SpecifiedDealings" )]
    public class SpecifiedDealingsCollection: List<SpecifiedDealings> {}

    /// <summary>
    /// Details of specified country dealings
    /// </summary>
    [DataContract(Name = "SpecifiedDealings", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SpecifiedDealings
    {

        /// <summary>
        /// Specified country dealings - Activity code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryActivityC { get; set; }

        /// <summary>
        /// Specified country dealings - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Specified country dealings - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? RevenueTotalA { get; set; }
    }

    /// <summary>
    /// Dealings with specified country
    /// </summary>
    [CollectionDataContract(Name = "SpecifiedCountryCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="SpecifiedCountry" )]
    public class SpecifiedCountryCollection: List<SpecifiedCountry> {}

    /// <summary>
    /// Dealings with specified country
    /// </summary>
    [DataContract(Name = "SpecifiedCountry", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SpecifiedCountry
    {

        /// <summary>
        /// International dealings - Specified country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public SpecifiedDealingsCollection SpecifiedDealingsCollection { get; set; }

        /// <summary>
        /// Specified country dealings - All other expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? ExpenseOtherA { get; set; }

        /// <summary>
        /// Specified country dealings - All other revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? RevenueOtherA { get; set; }
    }

    /// <summary>
    /// Tangible property dealings of revenue nature
    /// </summary>
    [DataContract(Name = "TangiblePropertyRevenue", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class TangiblePropertyRevenue
    {

        /// <summary>
        /// Tangible property - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Tangible property - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? TotalA { get; set; }

        /// <summary>
        /// Tangible property - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Tangible property - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Royalties dealings
    /// </summary>
    [DataContract(Name = "Royalties", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Royalties
    {

        /// <summary>
        /// Royalties - Deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseDeductionsTotalA { get; set; }

        /// <summary>
        /// Royalties - Income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomeIncludedInAssessableTotalA { get; set; }

        /// <summary>
        /// Royalties - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Royalties - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Licence fees dealings
    /// </summary>
    [DataContract(Name = "LicenceFees", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class LicenceFees
    {

        /// <summary>
        /// Licence fees - Deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseDeductionsTotalA { get; set; }

        /// <summary>
        /// Licence fees - Income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomeIncludedInAssessableTotalA { get; set; }

        /// <summary>
        /// Licence fees - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Licence fees - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Rent or leasing dealings
    /// </summary>
    [DataContract(Name = "RentOrLeasing", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RentOrLeasing
    {

        /// <summary>
        /// Rent/leasing - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Rent/leasing - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Rent/leasing - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Rent/leasing - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Treasury related services
    /// </summary>
    [DataContract(Name = "TreasuryServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class TreasuryServices
    {

        /// <summary>
        /// Treasury related services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Treasury related services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Treasury related services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Treasury related services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Management and administration services
    /// </summary>
    [DataContract(Name = "ManagementAndAdministrationServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ManagementAndAdministrationServices
    {

        /// <summary>
        /// Management and administration services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Management and administration services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Management and administration services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Management and administration services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Insurance services
    /// </summary>
    [DataContract(Name = "InsuranceServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class InsuranceServices
    {

        /// <summary>
        /// Insurance services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Insurance services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Insurance services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Insurance services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Reinsurance services
    /// </summary>
    [DataContract(Name = "ReinsuranceServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ReinsuranceServices
    {

        /// <summary>
        /// Reinsurance services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Reinsurance services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Reinsurance services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Reinsurance services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Research and development services
    /// </summary>
    [DataContract(Name = "RAndDServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RAndDServices
    {

        /// <summary>
        /// Research and development services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Research and development services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Research and development services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Research and development services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Sales and marketing services
    /// </summary>
    [DataContract(Name = "SalesAndMarketingServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SalesAndMarketingServices
    {

        /// <summary>
        /// Sales and marketing services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Sales and marketing services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Sales and marketing services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Sales and marketing services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Software and information technology services
    /// </summary>
    [DataContract(Name = "SoftwareAndITServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SoftwareAndITServices
    {

        /// <summary>
        /// Software and information technology services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Software and information technology services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Software and information technology services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Software and information technology services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Technical services
    /// </summary>
    [DataContract(Name = "TechnicalServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class TechnicalServices
    {

        /// <summary>
        /// Technical services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Technical services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Technical services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Technical services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Logistics services
    /// </summary>
    [DataContract(Name = "LogisticsServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class LogisticsServices
    {

        /// <summary>
        /// Logistics services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Logistics services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Logistics services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Logistics services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Asset management services
    /// </summary>
    [DataContract(Name = "AssetManagementServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class AssetManagementServices
    {

        /// <summary>
        /// Asset management services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Asset management services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Asset management services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Asset management services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Other services
    /// </summary>
    [DataContract(Name = "OtherServices", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class OtherServices
    {

        /// <summary>
        /// Other services - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Other services - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Other services - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Other services - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }

        /// <summary>
        /// Other services - Description
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public string InternationalDealingsDescriptionT { get; set; }
    }

    /// <summary>
    /// Service arrangements
    /// </summary>
    [DataContract(Name = "ServiceArrangements", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ServiceArrangements
    {

        [DataMember(EmitDefaultValue = false, Order = 1)]
        public TreasuryServices TreasuryServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public ManagementAndAdministrationServices ManagementAndAdministrationServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 3)]
        public InsuranceServices InsuranceServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 4)]
        public ReinsuranceServices ReinsuranceServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 5)]
        public RAndDServices RAndDServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 6)]
        public SalesAndMarketingServices SalesAndMarketingServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 7)]
        public SoftwareAndITServices SoftwareAndITServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 8)]
        public TechnicalServices TechnicalServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 9)]
        public LogisticsServices LogisticsServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 10)]
        public AssetManagementServices AssetManagementServices { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 11)]
        public OtherServices OtherServices { get; set; }
    }
    
    [CollectionDataContract(Name = "InternationalDealingsRelatedPartyTransactionTypeCCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="InternationalDealingsRelatedPartyTransactionTypeC")]
    public class InternationalDealingsRelatedPartyTransactionTypeCCollection: List<string> {}

    /// <summary>
    /// Derivative transactions
    /// </summary>
    [DataContract(Name = "Derivatives", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Derivatives
    {

        /// <summary>
        /// Derivatives - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Derivatives - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Derivatives - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Derivatives - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }

        /// <summary>
        /// Principle derivative types - Derivative code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public InternationalDealingsRelatedPartyTransactionTypeCCollection InternationalDealingsRelatedPartyTransactionTypeCCollection { get; set; }

        /// <summary>
        /// Did you engage in the trading of derivatives globally through a trading structure in which you shared global profits from these activities with international related parties?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public bool InternationalDealingsTradingGlobalI { get; set; }
    }

    /// <summary>
    /// Debt factoring arrangements
    /// </summary>
    [DataContract(Name = "DebtFactoring", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class DebtFactoring
    {

        /// <summary>
        /// Debt factoring - Book value
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseBookValueA { get; set; }

        /// <summary>
        /// Debt factoring - Consideration
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? ExpenseConsiderationA { get; set; }

        /// <summary>
        /// Debt factoring - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Debt factoring - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Securitisation arrangements
    /// </summary>
    [DataContract(Name = "Securitisation", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Securitisation
    {

        /// <summary>
        /// Securitisation - Book value
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseBookValueA { get; set; }

        /// <summary>
        /// Securitisation - Consideration
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? ExpenseConsiderationA { get; set; }

        /// <summary>
        /// Securitisation - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Securitisation - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Interest bearing loans dealings
    /// </summary>
    [DataContract(Name = "InterestBearingLoans", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class InterestBearingLoans
    {

        /// <summary>
        /// Interest bearing loans - Average balance - Amounts borrowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? LiabilitiesBorrowedAverageBalanceA { get; set; }

        /// <summary>
        /// Interest bearing loans - Average balance - Amounts loaned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsLoanedAverageBalanceA { get; set; }
    }

    /// <summary>
    /// Interest free loans dealings
    /// </summary>
    [DataContract(Name = "InterestFreeLoans", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class InterestFreeLoans
    {

        /// <summary>
        /// Interest free loans - Average balance - Amounts borrowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? LiabilitiesBorrowedAverageBalanceA { get; set; }

        /// <summary>
        /// Interest free loans - Average balance - Amounts loaned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsLoanedAverageBalanceA { get; set; }
    }

    /// <summary>
    /// Interest dealings
    /// </summary>
    [DataContract(Name = "Interest", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Interest
    {

        /// <summary>
        /// Interest - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Interest - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Interest - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Interest - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Guarantees dealings
    /// </summary>
    [DataContract(Name = "Guarantees", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Guarantees
    {

        /// <summary>
        /// Guarantees - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Guarantees - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Guarantees - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Guarantees - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Insurance dealings
    /// </summary>
    [DataContract(Name = "Insurance", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Insurance
    {

        /// <summary>
        /// Insurance - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Insurance - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Insurance - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Insurance - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Reinsurance dealings
    /// </summary>
    [DataContract(Name = "Reinsurance", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Reinsurance
    {

        /// <summary>
        /// Reinsurance - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Reinsurance - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Reinsurance - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Reinsurance - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Other financial dealings
    /// </summary>
    [DataContract(Name = "OtherFinancial", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class OtherFinancial
    {

        /// <summary>
        /// Other financial dealings - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Other financial dealings - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? RevenueTotalA { get; set; }

        /// <summary>
        /// Other financial dealings - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Other financial dealings - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }

        /// <summary>
        /// Other financial dealings - Description
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public string InternationalDealingsDescriptionT { get; set; }
    }

    /// <summary>
    /// Financial dealings other than derivative transactions or debt factoring or securitisation arrangements
    /// </summary>
    [DataContract(Name = "FinancialDealings", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class FinancialDealings
    {

        [DataMember(EmitDefaultValue = false, Order = 1)]
        public InterestBearingLoans InterestBearingLoans { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public InterestFreeLoans InterestFreeLoans { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 3)]
        public Interest Interest { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 4)]
        public Guarantees Guarantees { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 5)]
        public Insurance Insurance { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 6)]
        public Reinsurance Reinsurance { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 7)]
        public OtherFinancial OtherFinancial { get; set; }
    }

    /// <summary>
    /// Foreign exchange gain or loss
    /// </summary>
    [CollectionDataContract(Name = "GainOrLossCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="GainOrLoss" )]
    public class GainOrLossCollection: List<GainOrLoss> {}

    /// <summary>
    /// Foreign exchange gain or loss
    /// </summary>
    [DataContract(Name = "GainOrLoss", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class GainOrLoss
    {

        /// <summary>
        /// Foreign exchange - Currency
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string MiscellaneousFunctionalCurrencyC { get; set; }

        /// <summary>
        /// Foreign exchange losses deducted
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? InternationalDealingsLossesHighestNominalA { get; set; }

        /// <summary>
        /// Foreign exchange gains returned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? InternationalDealingsGainsHighestNominalA { get; set; }
    }

    /// <summary>
    /// Foreign exchange transaction type
    /// </summary>
    [CollectionDataContract(Name = "ForeignExchangeCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="ForeignExchange" )]
    public class ForeignExchangeCollection: List<ForeignExchange> {}

    /// <summary>
    /// Foreign exchange transaction type
    /// </summary>
    [DataContract(Name = "ForeignExchange", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ForeignExchange
    {

        /// <summary>
        /// Foreign exchange - Transaction type
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string InternationalDealingsTransactionTypeC { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public GainOrLossCollection GainOrLossCollection { get; set; }

        /// <summary>
        /// Foreign exchange - All other currencies - Losses deducted
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? InternationalDealingsLossesOtherA { get; set; }

        /// <summary>
        /// Foreign exchange - All other currencies - Gains returned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? InternationalDealingsGainsOtherA { get; set; }
    }

    /// <summary>
    /// Other dealings of revenue nature
    /// </summary>
    [DataContract(Name = "RevenueDealings", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RevenueDealings
    {

        /// <summary>
        /// Other dealings - Expenditure
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTotalA { get; set; }

        /// <summary>
        /// Other dealings - Revenue
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? TotalA { get; set; }

        /// <summary>
        /// Other dealings - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousArmsLengthPricingMethodC { get; set; }

        /// <summary>
        /// Other dealings - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }

        /// <summary>
        /// Other dealings - Description
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public string InternationalDealingsDescriptionT { get; set; }
    }

    /// <summary>
    /// Disposal or acquisition of tangible property
    /// </summary>
    [DataContract(Name = "TangiblePropertyNonRevenue", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class TangiblePropertyNonRevenue
    {

        /// <summary>
        /// Disposal or acquisition of tangible property - Consideration paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? AssetsConsiderationPaidA { get; set; }

        /// <summary>
        /// Disposal or acquisition of tangible property - Consideration received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsConsiderationReceivedA { get; set; }

        /// <summary>
        /// Disposal or acquisition of tangible property - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousAcquisitionsAndDisposalsPricingMethodC { get; set; }

        /// <summary>
        /// Disposal or acquisition of tangible property - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Assignment of intellectual property
    /// </summary>
    [DataContract(Name = "IntellectualProperty", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class IntellectualProperty
    {

        /// <summary>
        /// Assignment of intellectual property - Consideration paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? AssetsConsiderationPaidA { get; set; }

        /// <summary>
        /// Assignment of intellectual property - Consideration received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsConsiderationReceivedA { get; set; }

        /// <summary>
        /// Assignment of intellectual property - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousAcquisitionsAndDisposalsPricingMethodC { get; set; }

        /// <summary>
        /// Assignment of intellectual property - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Assignment of shares or other equity interests
    /// </summary>
    [DataContract(Name = "SharesOrOtherEquityInterests", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SharesOrOtherEquityInterests
    {

        /// <summary>
        /// Assignment of shares or other equity interests - Consideration paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? AssetsConsiderationPaidA { get; set; }

        /// <summary>
        /// Assignment of shares or other equity interests - Consideration received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsConsiderationReceivedA { get; set; }

        /// <summary>
        /// Assignment of shares or other equity interests - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousAcquisitionsAndDisposalsPricingMethodC { get; set; }

        /// <summary>
        /// Assignment of shares or other equity interests - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Assignment of loans or debts (not liabilities)
    /// </summary>
    [DataContract(Name = "LoansOrDebts", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class LoansOrDebts
    {

        /// <summary>
        /// Assignment of loans or debts - Consideration paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? AssetsConsiderationPaidA { get; set; }

        /// <summary>
        /// Assignment of loans or debts - Consideration received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsConsiderationReceivedA { get; set; }

        /// <summary>
        /// Assignment of loans or debts - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousAcquisitionsAndDisposalsPricingMethodC { get; set; }

        /// <summary>
        /// Assignment of loans or debts - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Other disposal or acquisition of intangible property
    /// </summary>
    [DataContract(Name = "IntangibleProperty", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class IntangibleProperty
    {

        /// <summary>
        /// Other disposal or acquisition of intangible property - Consideration paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? AssetsConsiderationPaidA { get; set; }

        /// <summary>
        /// Other disposal or acquisition of intangible property - Consideration received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsConsiderationReceivedA { get; set; }

        /// <summary>
        /// Other disposal or acquisition of intangible property - Main pricing methodology
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousAcquisitionsAndDisposalsPricingMethodC { get; set; }

        /// <summary>
        /// Other disposal or acquisition of intangible property - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }
    }

    /// <summary>
    /// Disposal or acquisition of property
    /// </summary>
    [DataContract(Name = "DisposalOrAcquisition", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class DisposalOrAcquisition
    {

        [DataMember(EmitDefaultValue = false, Order = 1)]
        public TangiblePropertyNonRevenue TangiblePropertyNonRevenue { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public IntellectualProperty IntellectualProperty { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 3)]
        public SharesOrOtherEquityInterests SharesOrOtherEquityInterests { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 4)]
        public LoansOrDebts LoansOrDebts { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 5)]
        public IntangibleProperty IntangibleProperty { get; set; }
    }

    /// <summary>
    /// RandD type services
    /// </summary>
    [DataContract(Name = "ResearchAndDevelopment", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ResearchAndDevelopment
    {

        /// <summary>
        /// RandD type services - Costs on which margin calculated
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal ExpenseCostPlusRemunerationA { get; set; }

        /// <summary>
        /// RandD type services - Cost-plus margin remuneration
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal IncomeCostPlusRemunerationA { get; set; }
    }

    /// <summary>
    /// Capital no payment
    /// </summary>
    [DataContract(Name = "CapitalNoPayment", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class CapitalNoPayment
    {

        /// <summary>
        /// Capital no payment - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Capital no payment - Nature of item
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string MiscellaneousNatureOfItemC { get; set; }
    }

    /// <summary>
    /// Revenue no payment
    /// </summary>
    [DataContract(Name = "RevenueNoPayment", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RevenueNoPayment
    {

        /// <summary>
        /// Revenue no payment - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Revenue no payment - Nature of item
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string MiscellaneousNatureOfItemC { get; set; }
    }

    /// <summary>
    /// Capital non-monetary payment
    /// </summary>
    [DataContract(Name = "CapitalNonMonetaryPayment", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class CapitalNonMonetaryPayment
    {

        /// <summary>
        /// Capital non-monetary payment - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Capital non-monetary payment - Nature of item
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string MiscellaneousNatureOfItemC { get; set; }
    }

    /// <summary>
    /// Revenue non-monetary payment
    /// </summary>
    [DataContract(Name = "RevenueNonMonetaryPayment", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RevenueNonMonetaryPayment
    {

        /// <summary>
        /// Revenue non-monetary payment - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Revenue non-monetary payment - Nature of item
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string MiscellaneousNatureOfItemC { get; set; }
    }

    /// <summary>
    /// Share-based employee remuneration
    /// </summary>
    [DataContract(Name = "ShareBasedRemuneration", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ShareBasedRemuneration
    {

        /// <summary>
        /// Recharge amounts - Deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseDeductionsTotalA { get; set; }

        /// <summary>
        /// Recharge amounts - Income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomeIncludedInAssessableTotalA { get; set; }
    }

    /// <summary>
    /// Restructuring event
    /// </summary>
    [CollectionDataContract(Name = "RestructuringEventCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="RestructuringEvent" )]
    public class RestructuringEventCollection: List<RestructuringEvent> {}

    /// <summary>
    /// Restructuring event
    /// </summary>
    [DataContract(Name = "RestructuringEvent", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RestructuringEvent
    {

        /// <summary>
        /// Restructuring event - Entity or branch
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsEntityC { get; set; }

        /// <summary>
        /// Restructuring event - Capital value
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string MiscellaneousCapitalValueC { get; set; }

        /// <summary>
        /// Restructuring event - Appendix 7 code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousNatureOfItemC { get; set; }

        /// <summary>
        /// Restructuring event - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Restructuring event - Percentage of dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public string MiscellaneousPercentageOfDealingsWithDocumentationC { get; set; }

        /// <summary>
        /// Restructuring event - Description
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public string InternationalDealingsDescriptionT { get; set; }

        /// <summary>
        /// Restructuring event - Was there a contemporaneous professional valuation study or transfer pricing analysis of the restructuring event undertaken?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 7)]
        public bool InternationalDealingsEventAnalysisI { get; set; }
    }

    /// <summary>
    /// Branch operations - Interest bearing loans
    /// </summary>
    [DataContract(Name = "BranchOperationsInterestBearingLoans", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class BranchOperationsInterestBearingLoans
    {

        /// <summary>
        /// Branch operations - Interest bearing loans - Average balance - Amounts borrowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? LiabilitiesBorrowedAverageBalanceA { get; set; }

        /// <summary>
        /// Branch operations - Interest bearing loans - Average balance - Amounts loaned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsLoanedAverageBalanceA { get; set; }

        /// <summary>
        /// Branch operations - Interest bearing loans - Interest - Amounts borrowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? ExpenseInterestBorrowedTotalA { get; set; }

        /// <summary>
        /// Branch operations - Interest bearing loans - Interest - Amounts loaned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? IncomeInterestLoanedTotalA { get; set; }
    }

    /// <summary>
    /// Branch operations - Interest free loans
    /// </summary>
    [DataContract(Name = "BranchOperationsInterestFreeLoans", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class BranchOperationsInterestFreeLoans
    {

        /// <summary>
        /// Branch operations - Interest free loans for TR 2005/11 - Average balance - Amounts borrowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? LiabilitiesBorrowedAverageBalanceA { get; set; }

        /// <summary>
        /// Branch operations - Interest free loans for TR 2005/11 - Average balance - Amounts loaned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetsLoanedAverageBalanceA { get; set; }
    }

    /// <summary>
    /// Internal trading stock transfers
    /// </summary>
    [DataContract(Name = "InternalTrading", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class InternalTrading
    {

        /// <summary>
        /// Internal trading stock transfers - Trading stock purchase costs
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseTradingStockPurchaseCostsA { get; set; }

        /// <summary>
        /// Internal trading stock transfers - Trading stock sales proceeds
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomeTradingStockSalesTotalA { get; set; }
    }

    /// <summary>
    /// Other internally recorded dealings
    /// </summary>
    [DataContract(Name = "BranchOperationsOther", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class BranchOperationsOther
    {

        /// <summary>
        /// Total amount claimed for other internally recorded dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? MiscellaneousInternallyRecordedDealingsAmountsClaimedTotalA { get; set; }

        /// <summary>
        /// Total amount returned for other internally recorded dealings
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousInternallyRecordedDealingsAmountsReturnedTotalA { get; set; }

        /// <summary>
        /// Description of amounts claimed/returned
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string IncomeDe { get; set; }
    }

    /// <summary>
    /// Financial arrangements
    /// </summary>
    [DataContract(Name = "FinancialArrangements", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class FinancialArrangements
    {

        /// <summary>
        /// Average quarterly balance of debt interests - Amounts received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ExpenseInterestDebtReceivedAverageBalanceA { get; set; }

        /// <summary>
        /// Average quarterly balance of debt interests - Amounts provided
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomeInterestDebtProvidedAverageBalanceA { get; set; }

        /// <summary>
        /// Average quarterly balance of equity interests - Amounts received
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? ExpenseInterestEquityReceivedAverageBalanceA { get; set; }

        /// <summary>
        /// Average quarterly balance of equity interests - Amounts provided
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? IncomeInterestEquityProvidedAverageBalanceA { get; set; }
    }

    /// <summary>
    /// Taxation of Financial Arrangements (TOFA)
    /// </summary>
    [DataContract(Name = "TOFA", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class TOFA
    {

        /// <summary>
        /// Total TOFA value of those financial arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal InternationalDealingsTaxationOfFinancialArrangementsTotalValueA { get; set; }

        /// <summary>
        /// Total value of TOFA gains for those financial arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal InternationalDealingsTaxationOfFinancialArrangementsTotalGainsA { get; set; }

        /// <summary>
        /// Total value of TOFA losses for those financial arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal InternationalDealingsTaxationOfFinancialArrangementsTotalLossesA { get; set; }
    }
    
    [CollectionDataContract(Name = "InternationalDealingsTaxTimingMethodElectionsCCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="InternationalDealingsTaxTimingMethodElectionsC")]
    public class InternationalDealingsTaxTimingMethodElectionsCCollection: List<string> {}

    /// <summary>
    /// Listed countries
    /// </summary>
    [DataContract(Name = "Listed", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Listed
    {

        /// <summary>
        /// Number of CFCs and CFTs in which you had an interest at the end of your income year - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal MiscellaneousControlledForeignCompaniesTrustsInterestCt { get; set; }

        /// <summary>
        /// Number of acquired CFCs and CFTs - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousControlledForeignCompanyTrustInterestAcquiredCt { get; set; }

        /// <summary>
        /// Number of disposed CFCs and CFTs - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? MiscellaneousControlledForeignCompanyTrustInterestDisposedCt { get; set; }

        /// <summary>
        /// Have your CFCs satisfied the active income test for their statutory accounting period(s) - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousControlledForeignCompaniesActiveIncomeTestSatisfiedC { get; set; }
    }

    /// <summary>
    /// Specified countries
    /// </summary>
    [DataContract(Name = "Specified", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Specified
    {

        /// <summary>
        /// Number of CFCs and CFTs in which you had an interest at the end of your income year - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal MiscellaneousControlledForeignCompaniesTrustsInterestCt { get; set; }

        /// <summary>
        /// Number of acquired CFCs and CFTs - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousControlledForeignCompanyTrustInterestAcquiredCt { get; set; }

        /// <summary>
        /// Number of disposed CFCs and CFTs - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? MiscellaneousControlledForeignCompanyTrustInterestDisposedCt { get; set; }

        /// <summary>
        /// Have your CFCs satisfied the active income test for their statutory accounting period(s) - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousControlledForeignCompaniesActiveIncomeTestSatisfiedC { get; set; }
    }

    /// <summary>
    /// Unlisted countries
    /// </summary>
    [DataContract(Name = "Unlisted", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Unlisted
    {

        /// <summary>
        /// Number of CFCs and CFTs in which you had an interest at the end of your income year - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal MiscellaneousControlledForeignCompaniesTrustsInterestCt { get; set; }

        /// <summary>
        /// Number of acquired CFCs and CFTs - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousControlledForeignCompanyTrustInterestAcquiredCt { get; set; }

        /// <summary>
        /// Number of disposed CFCs and CFTs - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? MiscellaneousControlledForeignCompanyTrustInterestDisposedCt { get; set; }

        /// <summary>
        /// Have your CFCs satisfied the active income test for their statutory accounting period(s) - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousControlledForeignCompaniesActiveIncomeTestSatisfiedC { get; set; }
    }

    /// <summary>
    /// Listed countries - CFC amounts
    /// </summary>
    [DataContract(Name = "ListedCFCAmounts", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ListedCFCAmounts
    {

        /// <summary>
        /// Total amount of tainted interest income excluded from passive income of CFCs (excluding CFCs with banking licences in their country) - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? IncomeControlledForeignCompaniesExcludedTaintedInterestIncomeA { get; set; }

        /// <summary>
        /// Number of CFCs which excluded tainted interest income from passive income (excluding CFCs with banking licences in their country) - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousControlledForeignCompanyExcludedTaintedInterestIncomeCt { get; set; }

        /// <summary>
        /// Section 456 - CFCs attributable income - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? IncomeControlledForeignCompaniesAttributableIncomeA { get; set; }

        /// <summary>
        /// Gross revenue included in the gross turnover of CFCs that have satisfied the active income test - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? IncomeGrossRevenueActiveIncomeTestSatisfiedA { get; set; }

        /// <summary>
        /// Gross revenue included in the gross turnover of CFCs that have not satisfied the active income test - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal? IncomeGrossRevenueActiveIncomeTestNotSatisfiedA { get; set; }

        /// <summary>
        /// Adjusted tainted income that is eligible designated concession income - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public decimal? IncomeControlledForeignCompaniesAdjustedTaintedConcessionIncomeA { get; set; }

        /// <summary>
        /// Adjusted tainted income not treated as derived from sources in listed countries - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 7)]
        public decimal? IncomeControlledForeignCompaniesAdjustedTaintedIncomeNotDerivedA { get; set; }

        /// <summary>
        /// Other notional assessable income - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 8)]
        public decimal? IncomeControlledForeignCompaniesOtherNotionalAssessableIncomeA { get; set; }

        /// <summary>
        /// Subtotal notional assessable income - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 9)]
        public decimal? IncomeControlledForeignCompaniesNotionalAssessableIncomeTotalA { get; set; }

        /// <summary>
        /// Notional allowable deductions - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 10)]
        public decimal? IncomeControlledForeignCompaniesNotionalAllowableDeductionsA { get; set; }
    }

    /// <summary>
    /// Specified countries - CFC amounts
    /// </summary>
    [DataContract(Name = "SpecifiedCFCAmounts", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SpecifiedCFCAmounts
    {

        /// <summary>
        /// Total amount of tainted interest income excluded from passive income of CFCs (excluding CFCs with banking licences in their country) - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? IncomeControlledForeignCompaniesExcludedTaintedInterestIncomeA { get; set; }

        /// <summary>
        /// Number of CFCs which excluded tainted interest income from passive income (excluding CFCs with banking licences in their country) - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousControlledForeignCompanyExcludedTaintedInterestIncomeCt { get; set; }

        /// <summary>
        /// Section 456 - CFCs attributable income - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? IncomeControlledForeignCompaniesAttributableIncomeA { get; set; }

        /// <summary>
        /// Gross revenue included in the gross turnover of CFCs that have satisfied the active income test - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? IncomeGrossRevenueActiveIncomeTestSatisfiedA { get; set; }

        /// <summary>
        /// Gross revenue included in the gross turnover of CFCs that have not satisfied the active income test - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal? IncomeGrossRevenueActiveIncomeTestNotSatisfiedA { get; set; }

        /// <summary>
        /// Adjusted tainted income - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public decimal? IncomeControlledForeignCompaniesAdjustedTaintedIncomeA { get; set; }

        /// <summary>
        /// Other notional assessable income - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 7)]
        public decimal? IncomeControlledForeignCompaniesOtherNotionalAssessableIncomeA { get; set; }

        /// <summary>
        /// Subtotal notional assessable income - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 8)]
        public decimal? IncomeControlledForeignCompaniesNotionalAssessableIncomeTotalA { get; set; }

        /// <summary>
        /// Notional allowable deductions - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 9)]
        public decimal? IncomeControlledForeignCompaniesNotionalAllowableDeductionsA { get; set; }
    }

    /// <summary>
    /// Unlisted countries - CFC amounts
    /// </summary>
    [DataContract(Name = "UnlistedCFCAmounts", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class UnlistedCFCAmounts
    {

        /// <summary>
        /// Total amount of tainted interest income excluded from passive income of CFCs (excluding CFCs with banking licences in their country) - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? IncomeControlledForeignCompaniesExcludedTaintedInterestIncomeA { get; set; }

        /// <summary>
        /// Number of CFCs which excluded tainted interest income from passive income (excluding CFCs with banking licences in their country) - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? MiscellaneousControlledForeignCompanyExcludedTaintedInterestIncomeCt { get; set; }

        /// <summary>
        /// Section 456 - CFCs attributable income - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? IncomeControlledForeignCompaniesAttributableIncomeA { get; set; }

        /// <summary>
        /// Gross revenue included in the gross turnover of CFCs that have satisfied the active income test - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? IncomeGrossRevenueActiveIncomeTestSatisfiedA { get; set; }

        /// <summary>
        /// Gross revenue included in the gross turnover of CFCs that have not satisfied the active income test - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal? IncomeGrossRevenueActiveIncomeTestNotSatisfiedA { get; set; }

        /// <summary>
        /// Adjusted tainted income - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public decimal? IncomeControlledForeignCompaniesAdjustedTaintedIncomeA { get; set; }

        /// <summary>
        /// Other notional assessable income - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 7)]
        public decimal? IncomeControlledForeignCompaniesOtherNotionalAssessableIncomeA { get; set; }

        /// <summary>
        /// Subtotal notional assessable income - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 8)]
        public decimal? IncomeControlledForeignCompaniesNotionalAssessableIncomeTotalA { get; set; }

        /// <summary>
        /// Notional allowable deductions - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 9)]
        public decimal? IncomeControlledForeignCompaniesNotionalAllowableDeductionsA { get; set; }
    }

    /// <summary>
    /// Listed countries - Foreign branch operations
    /// </summary>
    [DataContract(Name = "ListedForeignBranchOperations", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ListedForeignBranchOperations
    {

        /// <summary>
        /// Section 23AH - Foreign branch income of Australian companies - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? IncomeForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncomeA { get; set; }

        /// <summary>
        /// Section 23AI - Amounts paid out of attributed CFC income - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomePaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncomeA { get; set; }

        /// <summary>
        /// Subdivision 768-A - foreign equity distributions on minimum 10% participation interests in foreign companies - Listed countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? IncomeNonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncomeA { get; set; }
    }

    /// <summary>
    /// Specified countries - Foreign branch operations
    /// </summary>
    [DataContract(Name = "SpecifiedForeignBranchOperations", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class SpecifiedForeignBranchOperations
    {

        /// <summary>
        /// Section 23AH - Foreign branch income of Australian companies - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? IncomeForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncomeA { get; set; }

        /// <summary>
        /// Section 23AI - Amounts paid out of attributed CFC income - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomePaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncomeA { get; set; }

        /// <summary>
        /// Subdivision 768-A - foreign equity distributions on minimum 10% participation interests in foreign companies - Specified countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? IncomeNonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncomeA { get; set; }
    }

    /// <summary>
    /// Unlisted countries - Foreign branch operations
    /// </summary>
    [DataContract(Name = "UnlistedForeignBranchOperations", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class UnlistedForeignBranchOperations
    {

        /// <summary>
        /// Section 23AH - Foreign branch income of Australian companies - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? IncomeForeignBranchProfitsOfAustralianCompaniesNonAssessableNonExemptIncomeA { get; set; }

        /// <summary>
        /// Section 23AI - Amounts paid out of attributed CFC income - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomePaidOutOfAttributedControlledForeignCompanyIncomeNonAssessableNonExemptIncomeA { get; set; }

        /// <summary>
        /// Subdivision 768-A - foreign equity distributions on minimum 10% participation interests in foreign companies - Other unlisted countries
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? IncomeNonPortfolioDividendFromForeignCompanyNonAssessableNonExemptIncomeA { get; set; }
    }

    /// <summary>
    /// Capital gains tax events
    /// </summary>
    [DataContract(Name = "CGTEvents", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class CGTEvents
    {

        /// <summary>
        /// Capital gain amounts
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? CapitalGainsTaxActiveForeignBusinessCapitalGainsA { get; set; }

        /// <summary>
        /// Capital gain reductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? IncomeTaxActiveForeignBusinessCapitalGainsReductionA { get; set; }

        /// <summary>
        /// Capital loss amounts
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? CapitalGainsTaxActiveForeignBusinessCapitalLossesA { get; set; }

        /// <summary>
        /// Capital loss reductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? IncomeTaxActiveForeignBusinessCapitalLossesReductionA { get; set; }
    }

    /// <summary>
    /// Transfer
    /// </summary>
    [CollectionDataContract(Name = "TransferCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="Transfer" )]
    public class TransferCollection: List<Transfer> {}

    /// <summary>
    /// Transfer
    /// </summary>
    [DataContract(Name = "Transfer", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Transfer
    {

        /// <summary>
        /// Transfer amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal MiscellaneousPropertyMoneyOrServicesA { get; set; }

        /// <summary>
        /// Appendix 8 exemption code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string ItemOrderN { get; set; }
    }

    /// <summary>
    /// Hub arrangement
    /// </summary>
    [CollectionDataContract(Name = "HubArrangementCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="HubArrangement" )]
    public class HubArrangementCollection: List<HubArrangement> {}

    /// <summary>
    /// Hub arrangement
    /// </summary>
    [DataContract(Name = "HubArrangement", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class HubArrangement
    {

        /// <summary>
        /// Type of hub
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string MiscellaneousC { get; set; }

        /// <summary>
        /// Value of expenses/imports in connection with each type of hub
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal ExpenseImportsA { get; set; }

        /// <summary>
        /// Value of revenue/exports in connection with each type of hub
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal RevenueExportsA { get; set; }
    }

    /// <summary>
    /// All ADI entities
    /// </summary>
    [DataContract(Name = "AllADI", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class AllADI
    {

        /// <summary>
        /// All ADI entities - (Adjusted) average equity capital
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? LiabilitiesEquityCapitalAdjustedAverageA { get; set; }

        /// <summary>
        /// All ADI entities - Safe harbour capital amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? SafeHarbourA { get; set; }

        /// <summary>
        /// All ADI entities - Equity capital shortfall amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? EquityShortfallA { get; set; }
    }

    /// <summary>
    /// Outward investing ADI
    /// </summary>
    [DataContract(Name = "OutwardInvestingADI", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class OutwardInvestingADI
    {

        /// <summary>
        /// Outward investing ADI - Average value of risk weighted assets
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? LiabilitiesRiskWeightedAssetsAverageValueA { get; set; }

        /// <summary>
        /// Outward investing ADI - Equity capital attributable to overseas permanent establishment(s)
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? LiabilitiesEquityCapitalAttributableToOverseasPermanentEstablishmentsA { get; set; }

        /// <summary>
        /// Outward investing ADI - Average value of risk weighted assets attributable to overseas permanent establishment(s)
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? LiabilitiesRiskWeightedAssetsOverseasPermanentEstablishmentsAverageValueTotalA { get; set; }

        /// <summary>
        /// Outward investing ADI - Average value of controlled foreign entity equity
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? LiabilitiesControlledForeignADIEntityEquityAverageValueA { get; set; }

        /// <summary>
        /// Outward investing ADI - Tier 1 prudential capital deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal? LiabilitiesTier1PrudentialCapitalDeductionA { get; set; }
    }

    /// <summary>
    /// Inward investing ADI
    /// </summary>
    [DataContract(Name = "InwardInvestingADI", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class InwardInvestingADI
    {

        /// <summary>
        /// Inward investing ADI - Average of risk weighted assets attributable to Australian permanent establishment(s)
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? RiskWeightedAssetsAttributableToAustralianPermanentEstablishmentsAverageA { get; set; }

        /// <summary>
        /// Inward investing ADI - Average value of dotation capital
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? DotationCapitalAverageValueA { get; set; }
    }

    /// <summary>
    /// All non-ADI entities
    /// </summary>
    [DataContract(Name = "AllNonADI", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class AllNonADI
    {

        /// <summary>
        /// All non-ADI entities - Average value of assets
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? AssetsValueAverageA { get; set; }

        /// <summary>
        /// All non-ADI entities - Asset revaluation amount for thin capitalisation purposes
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? AssetRevaluationA { get; set; }

        /// <summary>
        /// All non-ADI entities - Safe harbour debt amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? LiabilitiesDebtMaximumAllowableA { get; set; }

        /// <summary>
        /// All non-ADI entities - Excess debt amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? LiabilitiesExcessDebtA { get; set; }

        /// <summary>
        /// All non-ADI entities - Average value of non-debt liabilities
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal? LiabilitiesNonDebtLiabilitiesAverageValueA { get; set; }

        /// <summary>
        /// All non-ADI entities - Average value of associate entity debt
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public decimal? LiabilitiesAssociateEntityDebtAverageValueA { get; set; }

        /// <summary>
        /// All non-ADI entities - Average value of associate entity equity
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 7)]
        public decimal? AssociateEntityEquityAverageValueA { get; set; }

        /// <summary>
        /// All non-ADI entities - Average value of associate entity excess amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 8)]
        public decimal? LiabilitiesAssociateEntityExcessAverageValueA { get; set; }

        /// <summary>
        /// All non-ADI entities - Average value of excluded equity interests
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 9)]
        public decimal? ExcludedEquityInterestsAverageA { get; set; }
    }

    /// <summary>
    /// Financial entity
    /// </summary>
    [DataContract(Name = "FinancialEntity", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class FinancialEntity
    {

        /// <summary>
        /// Financial entity - Average zero capital amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ZeroCapitalAverageA { get; set; }

        /// <summary>
        /// Financial entity - Average on-lent amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? LiabilitiesOnLentAverageA { get; set; }
    }

    /// <summary>
    /// Outward investing entity
    /// </summary>
    [DataContract(Name = "OutwardInvestingEntity", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class OutwardInvestingEntity
    {

        /// <summary>
        /// Outward investing entity - Average value of controlled foreign entity equity
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? ControlledForeignNonAuthorisedDepositTakingInstitutionEntityEquityAverageValueA { get; set; }

        /// <summary>
        /// Outward investing entity - Average value of controlled foreign entity debt
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? ControlledForeignEntityDebtAverageValueA { get; set; }
    }

    /// <summary>
    /// ADI
    /// </summary>
    [DataContract(Name = "ADI", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ADI
    {

        /// <summary>
        /// ADI - Worldwide group capital ratio
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? WorldwideGroupCapitalRatioF { get; set; }

        /// <summary>
        /// ADI - Worldwide capital amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? WorldwideCapitalA { get; set; }
    }

    /// <summary>
    /// Non-ADI
    /// </summary>
    [DataContract(Name = "NonADI", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class NonADI
    {

        /// <summary>
        /// Non-ADI - Worldwide debt
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? WorldwideDebtTotalA { get; set; }

        /// <summary>
        /// Non-ADI - Worldwide equity
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? LiabilitiesWorldwideEquityA { get; set; }

        /// <summary>
        /// Non-ADI - Worldwide gearing debt amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? WorldwideGearingDebtA { get; set; }

        /// <summary>
        /// Non-ADI - Statement worldwide asset
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal? StatementWorldwideAssetA { get; set; }

        /// <summary>
        /// Non-ADI - Average Australian asset
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal? AverageAustralianAssetA { get; set; }
    }

    /// <summary>
    /// Thin capitalisation information
    /// </summary>
    [DataContract(Name = "ThinCapitalisation", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ThinCapitalisation
    {

        /// <summary>
        /// Has an Australian resident company elected under subdivision 820-FB of the ITAA 1997 to treat your qualifying Australian branch operations as part of a consolidated group, MEC group or a single company for thin capitalisation purposes?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public bool? LiabilitiesAustralianResidentCompanyElectedI { get; set; }

        /// <summary>
        /// Australian Business Number (ABN) of the entity making that election
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string AustralianBusinessNumberId { get; set; }

        /// <summary>
        /// Entity type code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string LiabilitiesEntityTypeC { get; set; }

        /// <summary>
        /// Did you change your entity status from 'general' to 'financial' during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public bool? LiabilitiesGeneralToFinancialStatusChangeI { get; set; }

        /// <summary>
        /// Average values calculation method code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public string LiabilitiesAveragingMethodAdoptedC { get; set; }

        /// <summary>
        /// Debt deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public decimal? LiabilitiesDeductionDebtA { get; set; }

        /// <summary>
        /// Debt deductions on debt from related non-residents
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 7)]
        public decimal? LiabilitiesRelatedNonResidentsDebtDeductionA { get; set; }

        /// <summary>
        /// Amount of debt deduction disallowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 8)]
        public decimal? LiabilitiesDeductionDebtDisallowedA { get; set; }

        /// <summary>
        /// Adjusted average debt
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 9)]
        public decimal? LiabilitiesDebtAdjustedAverageA { get; set; }

        /// <summary>
        /// Were you an Authorised Deposit-taking Institution (ADI) for the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 10)]
        public bool? LiabilitiesAuthorisedDepositTakingInstitutionI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 11)]
        public AllADI AllADI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 12)]
        public OutwardInvestingADI OutwardInvestingADI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 13)]
        public InwardInvestingADI InwardInvestingADI { get; set; }

        /// <summary>
        /// Were you a non-Authorised Deposit-taking Institution (non-ADI) for the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 14)]
        public bool? LiabilitiesNonAuthorisedDepositTakingInstitutionI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 15)]
        public AllNonADI AllNonADI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 16)]
        public FinancialEntity FinancialEntity { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 17)]
        public OutwardInvestingEntity OutwardInvestingEntity { get; set; }

        /// <summary>
        /// Did you rely on arm's length tests?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 18)]
        public bool? LiabilitiesArmsLengthTestsI { get; set; }

        /// <summary>
        /// Arm's length debt (non-ADI) or capital (ADI) amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 19)]
        public decimal? ArmsLengthDebtA { get; set; }

        /// <summary>
        /// Did you rely on worldwide gearing debt/capital tests?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 20)]
        public bool? LiabilitiesGearingDebtCapitalTestI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 21)]
        public ADI ADI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 22)]
        public NonADI NonADI { get; set; }
    }

    /// <summary>
    /// Notional amount of interest under Part IIIB
    /// </summary>
    [DataContract(Name = "NotionalAmount", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class NotionalAmount
    {

        /// <summary>
        /// Average quarterly notional amount taken to be borrowed under section 160ZZZ
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal FinancialServicesNotionalAverageBorrowingsA { get; set; }

        /// <summary>
        /// Main currency of the notional amount taken to be borrowed under section 160ZZZ
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string FinancialServicesNotionalAverageBorrowingsC { get; set; }

        /// <summary>
        /// Notional amount of interest taken to be paid under section 160ZZZA (excluding amounts attributable to OB activities of offshore banking units (OBUs))
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal FinancialServicesNonOffshoreBankingUnitNotionalInterestA { get; set; }

        /// <summary>
        /// Notional amount of interest taken to be paid under section 160ZZZA attributable to OB activities of OBUs
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal FinancialServicesOffshoreBankingUnitNotionalInterestA { get; set; }

        /// <summary>
        /// Amount of section 160ZZZJ withholding tax paid on notional interest amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal FinancialServicesNotionalInterestTaxWithholdingA { get; set; }
    }

    /// <summary>
    /// Notional derivative and foreign exchange transactions under Part IIIB
    /// </summary>
    [DataContract(Name = "NotionalDerivativeAndForeignExchange", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class NotionalDerivativeAndForeignExchange
    {

        /// <summary>
        /// Notional amount taken to be paid under section 160ZZZE
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal FinancialServicesNotionalDerivativePaidA { get; set; }

        /// <summary>
        /// Notional amount taken to be received under section 160ZZZE
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal FinancialServicesNotionalDerivativeReceivedA { get; set; }

        /// <summary>
        /// Notional amount taken to be paid under section 160ZZZF
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal FinancialServicesNotionalForeignExchangeTransactionPaidA { get; set; }

        /// <summary>
        /// Notional amount taken to be received under section 160ZZZF
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal FinancialServicesNotionalForeignExchangeTransactionReceivedA { get; set; }
    }

    /// <summary>
    /// Notional amounts of financial entity that has elected out of Part IIIB
    /// </summary>
    [DataContract(Name = "NotionalAmountElectedOut", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class NotionalAmountElectedOut
    {

        /// <summary>
        /// Average quarterly notional amount taken to be borrowed under section 160ZZZ
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal FinancialServicesElectedOutNotionalAverageBorrowingsA { get; set; }

        /// <summary>
        /// Main currency of the notional amount taken to be borrowed under section 160ZZZ
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string FinancialServicesElectedOutNotionalAverageBorrowingsC { get; set; }

        /// <summary>
        /// Notional amount of interest taken to be paid under section 160ZZZA (excluding amounts attributable to OB activities of offshore banking units (OBUs))
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal FinancialServicesElectedOutNonOffshoreBankingUnitNotionalInterestA { get; set; }

        /// <summary>
        /// Notional amount of interest taken to be paid under section 160ZZZA attributable to OB activities of OBUs
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal FinancialServicesElectedOutOffshoreBankingUnitNotionalInterestA { get; set; }

        /// <summary>
        /// Amount of section 160ZZZJ withholding tax paid on notional interest amount
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal FinancialServicesElectedOutNotionalInterestTaxWithholdingA { get; set; }
    }

    /// <summary>
    /// Borrowing
    /// </summary>
    [DataContract(Name = "Borrowing", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Borrowing
    {

        /// <summary>
        /// Borrowing - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Borrowing - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Borrowing - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? BorrowingRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Lending
    /// </summary>
    [DataContract(Name = "Lending", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Lending
    {

        /// <summary>
        /// Lending - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Lending - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Lending - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? LendingRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Guarantee-type
    /// </summary>
    [DataContract(Name = "GuaranteeType", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class GuaranteeType
    {

        /// <summary>
        /// Guarantee-type - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Guarantee-type - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Guarantee-type - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? GuaranteeTypeRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Trading
    /// </summary>
    [DataContract(Name = "Trading", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Trading
    {

        /// <summary>
        /// Trading - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Trading - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Trading - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? TradingRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Eligible contract
    /// </summary>
    [DataContract(Name = "EligibleContract", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class EligibleContract
    {

        /// <summary>
        /// Eligible contact - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Eligible contract - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Eligible contract - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? EligibleContractRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Investment
    /// </summary>
    [DataContract(Name = "Investment", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Investment
    {

        /// <summary>
        /// Investment - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Investment - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Investment - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? InvestmentRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Advisory
    /// </summary>
    [DataContract(Name = "Advisory", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Advisory
    {

        /// <summary>
        /// Advisory - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Advisory - Net OB income /loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Advisory - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? AdvisoryRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Hedging
    /// </summary>
    [DataContract(Name = "Hedging", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Hedging
    {

        /// <summary>
        /// Hedging - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Hedging - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Hedging - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? HedgingRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Leasing
    /// </summary>
    [DataContract(Name = "Leasing", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Leasing
    {

        /// <summary>
        /// Leasing - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Leasing - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Leasing - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? LeasingRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Other - as declared by regulation
    /// </summary>
    [DataContract(Name = "Other", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Other
    {

        /// <summary>
        /// Other - As declared by regulation - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Other - As declared by regulation - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Other - As declared by regulation - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? OtherRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Total assessable OB Income/less Total OB deductions
    /// </summary>
    [DataContract(Name = "Total", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Total
    {

        /// <summary>
        /// Total assessable OB Income / less Total OB deductions - Assessable OB income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal FinancialServicesIncomeAssessableA { get; set; }

        /// <summary>
        /// Total assessable OB Income / less Total OB deductions - Net OB income/loss
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal FinancialServicesIncomeOrLossNetA { get; set; }

        /// <summary>
        /// Total assessable OB Income / less Total OB deductions - Assessable OB income from related parties
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal? TotalRelatedPartiesFinancialServicesIncomeAssessableA { get; set; }
    }

    /// <summary>
    /// Offshore banking income or loss or deductions
    /// </summary>
    [DataContract(Name = "OffshoreBanking", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class OffshoreBanking
    {

        [DataMember(EmitDefaultValue = false, Order = 1)]
        public Borrowing Borrowing { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 2)]
        public Lending Lending { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 3)]
        public GuaranteeType GuaranteeType { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 4)]
        public Trading Trading { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 5)]
        public EligibleContract EligibleContract { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 6)]
        public Investment Investment { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 7)]
        public Advisory Advisory { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 8)]
        public Hedging Hedging { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 9)]
        public Leasing Leasing { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 10)]
        public Other Other { get; set; }

        /// <summary>
        /// General OB deduction and apportionable OB deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 11)]
        public decimal? GeneralFinancialServicesOffshoreBankingDeductionAndApportionableOffshoreBankingDeductionA { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 12)]
        public Total Total { get; set; }

        /// <summary>
        /// Eligible fraction of foreign income tax on OB income claimed under division 770
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 13)]
        public decimal ForeignIncomeTaxFinancialServicesIncomeForeignIncomeTaxEligibleFractionClaimedA { get; set; }
    }

    /// <summary>
    /// Conduit foreign income
    /// </summary>
    [DataContract(Name = "ConduitForeignIncome", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class ConduitForeignIncome
    {

        /// <summary>
        /// Balance of conduit foreign income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal? InternationalDealingsBalanceA { get; set; }

        /// <summary>
        /// Conduit foreign income distributed during income year
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal? InternationalDealingsDistributedA { get; set; }
    }

    /// <summary>
    /// Unfranked non portfolio dividend account
    /// </summary>
    [DataContract(Name = "Unfranked", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class Unfranked
    {

        /// <summary>
        /// Balance of unfranked non-portfolio dividend account at year end
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal InternationalDealingsNonPortfolioDividendAccountA { get; set; }

        /// <summary>
        /// Conduit foreign income included in balance of unfranked non-portfolio dividend account at year end - code
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public bool InternationalDealingsNonPortfolioAccountConduitForeignIncomeIncludedI { get; set; }
    }

    /// <summary>
    /// Material arrangements
    /// </summary>
    [CollectionDataContract(Name = "MaterialArrangementsCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="MaterialArrangements" )]
    public class MaterialArrangementsCollection: List<MaterialArrangements> {}

    /// <summary>
    /// Material arrangements
    /// </summary>
    [DataContract(Name = "MaterialArrangements", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class MaterialArrangements
    {

        /// <summary>
        /// Type of hybrid mismatch arrangement
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string MiscellaneousHybridMismatchArrangementC { get; set; }

        /// <summary>
        /// Hybrid mismatch arrangement - Foreign country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Total amount of payments made during income year
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal MiscellaneousHybridMismatchPaymentsA { get; set; }

        /// <summary>
        /// Total amount of deductions denied or amount of income inclusion
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal MiscellaneousHybridMismatchDeductionsDeniedOrIncomeInclusionA { get; set; }

        /// <summary>
        /// Reason for difference
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public string MiscellaneousHybridMismatchDifferenceReasonC { get; set; }

        /// <summary>
        /// Were you the recipient of the payment?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public bool MiscellaneousHybridMismatchPaymentRecipientI { get; set; }
    }

    /// <summary>
    /// Structured arrangement
    /// </summary>
    [DataContract(Name = "StructuredArrangement", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class StructuredArrangement
    {

        /// <summary>
        /// Total amount of the importing payments you made under the structured arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal MiscellaneousHybridMismatchPaymentsA { get; set; }

        /// <summary>
        /// Total amount of the offshore hybrid mismatch under the structured arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal MiscellaneousHybridMismatchA { get; set; }

        /// <summary>
        /// Total amount of deductions disallowed for structured arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal MiscellaneousHybridMismatchDeductionDisallowedA { get; set; }
    }

    /// <summary>
    /// Non-structured arrangement
    /// </summary>
    [DataContract(Name = "NonStructuredArrangement", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class NonStructuredArrangement
    {

        /// <summary>
        /// Total amount of the offshore hybrid mismatch under non-structured arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public decimal MiscellaneousHybridMismatchA { get; set; }

        /// <summary>
        /// Total amount of deductions disallowed for non-structured arrangements
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal MiscellaneousHybridMismatchDeductionDisallowedA { get; set; }
    }

    /// <summary>
    /// Material Offshore hybrid mismatch
    /// </summary>
    [CollectionDataContract(Name = "MaterialOffshoreHybridMismatchCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="MaterialOffshoreHybridMismatch" )]
    public class MaterialOffshoreHybridMismatchCollection: List<MaterialOffshoreHybridMismatch> {}

    /// <summary>
    /// Material Offshore hybrid mismatch
    /// </summary>
    [DataContract(Name = "MaterialOffshoreHybridMismatch", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class MaterialOffshoreHybridMismatch
    {

        /// <summary>
        /// Type of offshore hybrid mismatch
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string MiscellaneousHybridMismatchArrangementC { get; set; }

        /// <summary>
        /// Amount of offshore hybrid mismatch
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal MiscellaneousA { get; set; }

        /// <summary>
        /// Type of the importing payments
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public string MiscellaneousHybridMismatchPaymentsC { get; set; }

        /// <summary>
        /// Amount of importing payments (including amounts that would be an importing payment if section 832-625(3)(b) of the ITAA 1997 was disregarded)
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public decimal MiscellaneousHybridMismatchPaymentsA { get; set; }

        /// <summary>
        /// Amount of deductions disallowed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public decimal MiscellaneousHybridMismatchDeductionDisallowedA { get; set; }

        /// <summary>
        /// Reason the deductions disallowed were less than the importing payments
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public string MiscellaneousHybridMismatchDeductionDisallowedDifferenceReasonC { get; set; }
    }

    /// <summary>
    /// Hybrid payer mismatch
    /// </summary>
    [CollectionDataContract(Name = "HybridPayerMismatchCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="HybridPayerMismatch" )]
    public class HybridPayerMismatchCollection: List<HybridPayerMismatch> {}

    /// <summary>
    /// Hybrid payer mismatch
    /// </summary>
    [DataContract(Name = "HybridPayerMismatch", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class HybridPayerMismatch
    {

        /// <summary>
        /// Foreign country of interposed entity
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string OrganisationDetailsInternationalRelatedPartyCountryC { get; set; }

        /// <summary>
        /// Amount of payment
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public decimal MiscellaneousHybridMismatchPaymentsA { get; set; }

        /// <summary>
        /// Amount of deductions denied
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public decimal MiscellaneousHybridMismatchDeductionsDeniedA { get; set; }

        /// <summary>
        /// Reason - Hybrid payer mismatch exception
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public string MiscellaneousHybridMismatchExceptionReasonC { get; set; }
    }

    /// <summary>
    /// Hybrid arrangement restructure
    /// </summary>
    [CollectionDataContract(Name = "HybridArrangementRestructureCollection", Namespace = "http://www.sbr.gov.au/ato/ids", ItemName="HybridArrangementRestructure" )]
    public class HybridArrangementRestructureCollection: List<HybridArrangementRestructure> {}

    /// <summary>
    /// Hybrid arrangement restructure
    /// </summary>
    [DataContract(Name = "HybridArrangementRestructure", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class HybridArrangementRestructure
    {

        /// <summary>
        /// Restructuring event - Description
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string InternationalDealingsDescriptionT { get; set; }

        /// <summary>
        /// As a result of the restructure, has your taxable income remained the same or decreased if compared to the replaced hybrid arrangement before the application of the hybrid mismatch rules?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public bool InternationalDealingsHybridEventAnalysisI { get; set; }
    }

    /// <summary>
    /// Reporting party
    /// </summary>
    [DataContract(Name = "RP", Namespace = "http://www.sbr.gov.au/ato/ids")]
    public class RP
    {

        /// <summary>
        /// Business entity tax file number
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 1)]
        public string TaxFileNumberId { get; set; }

        /// <summary>
        /// Does Country-by-Country reporting apply to you?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 2)]
        public bool InternationalDealingsCountryByCountryReportApplicabilityI { get; set; }

        /// <summary>
        /// Have you lodged Part A of your local file at the same time as your income tax return?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 3)]
        public bool? InternationalDealingsLocalFilePartAVoluntaryLodgmentI { get; set; }

        /// <summary>
        /// Is the total of your international related party dealings over $2 million?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 4)]
        public bool? InternationalDealingsRelatedPartiesTransactionsExcessAggregateValueI { get; set; }

        /// <summary>
        /// Are you a small business entity, not a significant global entity and your international related party dealings do not exceed $5 million and 50% of your current year aggregated turnover?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 5)]
        public bool? InternationalDealingsSmallBusinessConcessionsEligibilityI { get; set; }

        /// <summary>
        /// Did you have dealings with international related parties, apart from the dealings with related parties located in specified countries?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 6)]
        public bool? InternationalDealingsRelatedPartiesTransactionsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 7)]
        public ForeignCountryCollection ForeignCountryCollection { get; set; }

        /// <summary>
        /// Did you have dealings with international related parties located in specified countries?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 8)]
        public bool? InternationalDealingsSpecifiedCountriesTransactionsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 9)]
        public SpecifiedCountryCollection SpecifiedCountryCollection { get; set; }

        /// <summary>
        /// Did you have any international related party dealings involving tangible property of a revenue nature, including trading stock and raw materials?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 10)]
        public bool? InternationalDealingsTransactionsTangiblePropertyRevenueI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 11)]
        public TangiblePropertyRevenue TangiblePropertyRevenue { get; set; }

        /// <summary>
        /// Did you have any international related party dealings involving royalties or licence fees?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 12)]
        public bool? InternationalDealingsTransactionsRoyaltiesLicenceFeesI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 13)]
        public Royalties Royalties { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 14)]
        public LicenceFees LicenceFees { get; set; }

        /// <summary>
        /// Did you have any international related party dealings involving rent or leasing?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 15)]
        public bool? InternationalDealingsTransactionsRentLeasingI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 16)]
        public RentOrLeasing RentOrLeasing { get; set; }

        /// <summary>
        /// Did you have any service arrangements with international related parties?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 17)]
        public bool? InternationalDealingsTransactionsServiceArrangementsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 18)]
        public ServiceArrangements ServiceArrangements { get; set; }

        /// <summary>
        /// Did you have any derivative transactions with international related parties?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 19)]
        public bool? InternationalDealingsDerivativeTransactionsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 20)]
        public Derivatives Derivatives { get; set; }

        /// <summary>
        /// Did you enter into any debt factoring or securitisation arrangements with international related parties?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 21)]
        public bool? InternationalDealingsDebtFactoringSecuritisationI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 22)]
        public DebtFactoring DebtFactoring { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 23)]
        public Securitisation Securitisation { get; set; }

        /// <summary>
        /// Did you have any dealings of a financial nature other than those listed under derivative transactions or debt factoring or securitisation arrangements with international related parties?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 24)]
        public bool? InternationalDealingsOtherFinancialDealingsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 25)]
        public FinancialDealings FinancialDealings { get; set; }

        /// <summary>
        /// Have you returned a foreign exchange gain or deducted a foreign exchange loss in relation to dealings with international related parties?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 26)]
        public bool? InternationalDealingsForeignExchangeGainLossI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 27)]
        public ForeignExchangeCollection ForeignExchangeCollection { get; set; }

        /// <summary>
        /// Did you have any other international related party dealings of a revenue nature not reported elsewhere?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 28)]
        public bool? InternationalDealingsOtherRevenueI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 29)]
        public RevenueDealings RevenueDealings { get; set; }

        /// <summary>
        /// Did you dispose of or acquire any tangible/intangible property of a non-revenue (capital) nature to or from international related parties not reported elsewhere?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 30)]
        public bool? MiscellaneousCapitalNatureI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 31)]
        public DisposalOrAcquisition DisposalOrAcquisition { get; set; }

        /// <summary>
        /// Did you receive or were entitled to receive remuneration from international related parties on a cost-plus basis for the performance of RandD type services?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 32)]
        public bool? MiscellaneousResearchAndDevelopmentCostPlusRemunerationI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 33)]
        public ResearchAndDevelopment ResearchAndDevelopment { get; set; }

        /// <summary>
        /// Did you provide any services or assets or liabilities or property – tangible or intangible (eg. intellectual property) or processes or rights or obligations for no payment or a non-monetary payment, or receive any of the same for a non-monetary payment to/from an international related party?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 34)]
        public bool? MiscellaneousReceivedOrProvidedServicesPropertyProcessesRightsOrObligationsForNonMonetaryConsiderationI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 35)]
        public CapitalNoPayment CapitalNoPayment { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 36)]
        public RevenueNoPayment RevenueNoPayment { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 37)]
        public CapitalNonMonetaryPayment CapitalNonMonetaryPayment { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 38)]
        public RevenueNonMonetaryPayment RevenueNonMonetaryPayment { get; set; }

        /// <summary>
        /// Did you provide or receive share-based employee remuneration to or from an international related party?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 39)]
        public bool? InternationalDealingsShareBasedEmployeeRemunerationI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 40)]
        public ShareBasedRemuneration ShareBasedRemuneration { get; set; }

        /// <summary>
        /// Were you a party to a cost contribution arrangement for developing, producing or obtaining assets or rights with an international related party?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 41)]
        public bool? InternationalDealingsCostContributionArrangementsI { get; set; }

        /// <summary>
        /// Did a restructuring event(s) occur in the current year involving international related parties or your branch operations?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 42)]
        public bool? InternationalDealingsRestructuringEventsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 43)]
        public RestructuringEventCollection RestructuringEventCollection { get; set; }

        /// <summary>
        /// During the last three income years (including the current income year) did you revalue any assets following a restructuring event(s) involving international related parties or your branch operations?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 44)]
        public bool? InternationalDealingsTransactionsRestructuringEventsAssetRevaluationI { get; set; }

        /// <summary>
        /// Do you have any branch operations (including Australian branch operations if you are a non-resident)?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 45)]
        public bool InternationalDealingsBranchOperationsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 46)]
        public BranchOperationsInterestBearingLoans BranchOperationsInterestBearingLoans { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 47)]
        public BranchOperationsInterestFreeLoans BranchOperationsInterestFreeLoans { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 48)]
        public InternalTrading InternalTrading { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 49)]
        public BranchOperationsOther BranchOperationsOther { get; set; }

        /// <summary>
        /// Did you hold any financing arrangement during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 50)]
        public bool InternationalDealingsFinancialArrangementsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 51)]
        public FinancialArrangements FinancialArrangements { get; set; }

        /// <summary>
        /// Did you have a financial arrangement for the purposes of Division 230 that did not give rise to a debt interest for the purposes of Division 974?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 52)]
        public bool InternationalDealingsTaxationOfFinancialArrangementsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 53)]
        public TOFA TOFA { get; set; }

        /// <summary>
        /// Are you subject to the Taxation of Financial Arrangements rules contained in Division 230 of the ITAA 1997?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 54)]
        public bool InternationalDealingsTaxationOfFinancialArrangementsRulesAppliedI { get; set; }

        /// <summary>
        /// Tax timing method election made
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 55)]
        public InternationalDealingsTaxTimingMethodElectionsCCollection InternationalDealingsTaxTimingMethodElectionsCCollection { get; set; }

        /// <summary>
        /// Did you have any interests in Controlled Foreign Companies (CFCs) or Controlled Foreign Trusts (CFTs)?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 56)]
        public bool MiscellaneousInterestInControlledForeignCompaniesAndControlledForeignTrustsI { get; set; }

        /// <summary>
        /// Did you acquire any interests in CFCs or CFTs during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 57)]
        public bool? MiscellaneousControlledForeignCompanyTrustInterestAcquiredI { get; set; }

        /// <summary>
        /// Did you dispose of any interests in CFCs or CFTs during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 58)]
        public bool? MiscellaneousControlledForeignCompanyTrustInterestDisposedI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 59)]
        public Listed Listed { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 60)]
        public Specified Specified { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 61)]
        public Unlisted Unlisted { get; set; }

        /// <summary>
        /// Did you exclude tainted interest income from the passive income of a CFC which was an AFI subsidiary?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 62)]
        public bool? MiscellaneousControlledForeignCompaniesExcludedTaintedInterestIncomeI { get; set; }

        /// <summary>
        /// Did your AFI subsidiary CFCs have banking licences in their countries?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 63)]
        public bool? MiscellaneousControlledForeignCompaniesBankingLicencesI { get; set; }

        /// <summary>
        /// Did your AFI subsidiary CFCs principally derive their income from the lending of money?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 64)]
        public bool? MiscellaneousControlledForeignCompaniesIncomeMoneyLendingI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 65)]
        public ListedCFCAmounts ListedCFCAmounts { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 66)]
        public SpecifiedCFCAmounts SpecifiedCFCAmounts { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 67)]
        public UnlistedCFCAmounts UnlistedCFCAmounts { get; set; }

        /// <summary>
        /// Total amount of tainted interest income excluded from passive income of CFCs (excluding CFCs with banking licences in their country) - Total
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 68)]
        public decimal? IncomeControlledForeignCompaniesExcludedTaintedInterestIncomeTotalA { get; set; }

        /// <summary>
        /// Section 456 - Total CFCs attributable income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 69)]
        public decimal? IncomeControlledForeignCompaniesAttributableIncomeTotalA { get; set; }

        /// <summary>
        /// Section 457 - CFCs Change of residence
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 70)]
        public decimal? IncomeControlledForeignCompaniesChangeOfResidenceIncomeA { get; set; }

        /// <summary>
        /// Section 459A - CFCs/CFTs and interposed Australian entities
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 71)]
        public decimal? IncomeControlledForeignCompaniesAndControlledForeignTrustsInterposedAustralianEntitiesAttributableIncomeTotalA { get; set; }

        /// <summary>
        /// Gross revenue of CFCs that have satisfied the active income test - Total
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 72)]
        public decimal? IncomeGrossRevenueActiveIncomeTestSatisfiedTotalA { get; set; }

        /// <summary>
        /// Gross revenue of CFCs that have not satisfied the active income test - Total
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 73)]
        public decimal? IncomeGrossRevenueActiveIncomeTestNotSatisfiedTotalA { get; set; }

        /// <summary>
        /// Total notional assessable income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 74)]
        public decimal? IncomeControlledForeignCompaniesNotionalAssessableIncomeTotalA { get; set; }

        /// <summary>
        /// Total notional allowable deductions
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 75)]
        public decimal? IncomeControlledForeignCompaniesNotionalAllowableDeductionsTotalA { get; set; }

        /// <summary>
        /// Do you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 76)]
        public bool IncomeForeignBranchOperationsInterestsInForeignCompaniesOrForeignTrustsI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 77)]
        public ListedForeignBranchOperations ListedForeignBranchOperations { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 78)]
        public SpecifiedForeignBranchOperations SpecifiedForeignBranchOperations { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 79)]
        public UnlistedForeignBranchOperations UnlistedForeignBranchOperations { get; set; }

        /// <summary>
        /// Non-deductible expenses incurred in deriving section 23AH non-assessable income
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 80)]
        public decimal? ExpenseNonDeductibleExemptIncomeA { get; set; }

        /// <summary>
        /// Did you have any debt deductions in earning non-assessable non-exempt foreign income?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 81)]
        public bool? IncomeTaxDeductionDebtEarningNonAssessableNonExemptForeignIncomeI { get; set; }

        /// <summary>
        /// Debt deductions in earning non-assessable non-exempt foreign income claimed
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 82)]
        public decimal? IncomeTaxDeductionDebtEarningNonAssessableNonExemptForeignIncomeTotalA { get; set; }

        /// <summary>
        /// Did you have any Capital Gains Tax (CGT) events in relation to your interest in a foreign company?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 83)]
        public bool? CapitalGainsTaxEventI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 84)]
        public CGTEvents CGTEvents { get; set; }

        /// <summary>
        /// During the last three income years (including the current income year) did you directly or indirectly transfer property, money or services to a non‑resident trust, where that non‑resident trust was still in existence during that income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 85)]
        public bool MiscellaneousTransferPropertyMoneyOrServicesI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 86)]
        public TransferCollection TransferCollection { get; set; }

        /// <summary>
        /// Were you a beneficiary of a non-resident trust or did you have an interest in, or an entitlement to acquire an interest in, either the income or capital of a non-resident trust during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 87)]
        public bool MiscellaneousNonResidentTrustInterestEntitlementOrBeneficiaryI { get; set; }

        /// <summary>
        /// Do any of the schedules within the Practical Compliance Guideline PCG 2017/1 apply to your offshore dealings?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 88)]
        public bool? MiscellaneousOffshoreDealingsComplianceI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 89)]
        public HubArrangementCollection HubArrangementCollection { get; set; }

        /// <summary>
        /// Were you a partner in a Foreign Hybrid Limited Partnership (FHLP) or shareholder in a Foreign Hybrid Company (FHC)?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 90)]
        public bool MiscellaneousForeignHybridLimitedPartnershipOrForeignHybridCompanyShareholderI { get; set; }

        /// <summary>
        /// Number of FHLPs or FHCs you had an interest in
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 91)]
        public decimal? MiscellaneousForeignHybridLimitedPartnershipOrForeignHybridCompanyInterestInCt { get; set; }

        /// <summary>
        /// Total amount of your share of FHLP/FHCs net income/profit
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 92)]
        public decimal? AssetsInvestmentForeignHybridLimitedPartnershipOrForeignHybridCompanyNetIncomeProfitTotalA { get; set; }

        /// <summary>
        /// Did the thin capitalisation rules affect you?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 93)]
        public bool LiabilitiesThinCapitalisationProvisionsAppliedI { get; set; }

        /// <summary>
        /// $2 million threshold test
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 94)]
        public bool? LiabilitiesThinCapitalisation2MillionThresholdTestI { get; set; }

        /// <summary>
        /// 90% asset threshold test
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 95)]
        public bool? LiabilitiesThinCapitalisation90PercentAssetThresholdTestI { get; set; }

        /// <summary>
        /// Exemption of certain special purpose entities
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 96)]
        public bool? LiabilitiesThinCapitalisationExemptionSpecialPurposeEntitiesI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 97)]
        public ThinCapitalisation ThinCapitalisation { get; set; }

        /// <summary>
        /// Are you a foreign bank or other qualifying financial entity that has not elected out of Part IIIB of the ITAA 1936?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 98)]
        public bool FinancialServicesForeignBankOrQualifyingFinancialEntityI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 99)]
        public NotionalAmount NotionalAmount { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 100)]
        public NotionalDerivativeAndForeignExchange NotionalDerivativeAndForeignExchange { get; set; }

        /// <summary>
        /// Are you a foreign bank or other qualifying financial entity that has elected out of Part IIIB of the ITAA 1936?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 101)]
        public bool? FinancialServicesForeignBankOrQualifyingFinancialEntityElectedOutI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 102)]
        public NotionalAmountElectedOut NotionalAmountElectedOut { get; set; }

        /// <summary>
        /// Did you have amounts denied under section 160ZZZL of the ITAA 1936?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 103)]
        public bool FinancialServicesNotionalPaymentDeniedI { get; set; }

        /// <summary>
        /// Amount denied under section 160ZZZL of the ITAA 1936
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 104)]
        public decimal? FinancialServicesNotionalPaymentDeniedA { get; set; }

        /// <summary>
        /// Were you an Offshore Banking Unit (OBU) or the head company of a consolidated group that included an OBU?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 105)]
        public bool FinancialServicesOffshoreBankingUnitOrHeadConsolidatedGroupI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 106)]
        public OffshoreBanking OffshoreBanking { get; set; }

        /// <summary>
        /// Did you have a Conduit Foreign Income balance and/or distribute amounts of Conduit Foreign Income during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 107)]
        public bool? InternationalDealingsConduitForeignIncomeI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 108)]
        public ConduitForeignIncome ConduitForeignIncome { get; set; }

        /// <summary>
        /// Do you have an unfranked non-portfolio dividend account (refer section 46FB ITAA)?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 109)]
        public bool? InternationalDealingsUnfrankedNonPortfolioDividendAccountI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 110)]
        public Unfranked Unfranked { get; set; }

        /// <summary>
        /// Did you pay amounts of interest exempt from withholding tax during the income year?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 111)]
        public bool? InternationalDealingsWithholdingTaxExemptNonResidentInterestPaidI { get; set; }

        /// <summary>
        /// Interest to financial institution exempt from withholding under a DTA
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 112)]
        public decimal? InternationalDealingsWithholdingTaxExemptNonResidentInterestPaidA { get; set; }

        /// <summary>
        /// DTA country
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 113)]
        public string InternationalDealingsDoubleTaxAgreementFinancialInstitutionsWithholdingExemptionCountryC { get; set; }

        /// <summary>
        /// Section 128F exempt interest paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 114)]
        public decimal? FInternationalDealingsWithholdingTaxExemptNonResidentInterestPaidA { get; set; }

        /// <summary>
        /// Section 128FA exempt interest paid
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 115)]
        public decimal? FAInternationalDealingsWithholdingTaxExemptNonResidentInterestPaidA { get; set; }

        /// <summary>
        /// Did the hybrid mismatch rules apply to you?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 116)]
        public bool MiscellaneousHybridMismatchI { get; set; }

        /// <summary>
        /// Have you made or received a payment at any time during the income year which gave rise to a deduction / non-inclusion or a deduction / deduction mismatch?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 117)]
        public bool? MiscellaneousHybridMismatchDeductionNonInclusionI { get; set; }

        /// <summary>
        /// Total amount of payments which gave rise to deduction/non-inclusion mismatches and deduction/deduction mismatches
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 118)]
        public decimal? MiscellaneousHybridMismatchPaymentsA { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 119)]
        public MaterialArrangementsCollection MaterialArrangementsCollection { get; set; }

        /// <summary>
        /// Have you made an importing payment under a structured arrangement?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 120)]
        public bool? MiscellaneousHybridMismatchPaymentI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 121)]
        public StructuredArrangement StructuredArrangement { get; set; }

        /// <summary>
        /// Do you have any other offshore hybrid mismatches within your Division 832 control groups?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 122)]
        public bool? MiscellaneousOffshoreHybridMismatchI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 123)]
        public NonStructuredArrangement NonStructuredArrangement { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 124)]
        public MaterialOffshoreHybridMismatchCollection MaterialOffshoreHybridMismatchCollection { get; set; }

        /// <summary>
        /// Did you pay an amount of interest or an amount under a derivative financial arrangement to an international related party which was not taxed or taxed at 10% or less?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 125)]
        public bool? MiscellaneousPaymentNotTaxedOrTaxed10PercentOrLessI { get; set; }

        /// <summary>
        /// Total amount of deductions subject to subdivision 832-J
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 126)]
        public decimal? MiscellaneousHybridMismatchDeductionsA { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 127)]
        public HybridPayerMismatchCollection HybridPayerMismatchCollection { get; set; }

        /// <summary>
        /// Did you or your international related parties restructure or replace an arrangement in the current or prior year which would have been subject to any of the hybrid mismatch rules if the arrangement was still in place?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 128)]
        public bool MiscellaneousHybridArrangementRestructureReplacementI { get; set; }

        [DataMember(EmitDefaultValue = false, Order = 129)]
        public HybridArrangementRestructureCollection HybridArrangementRestructureCollection { get; set; }

        /// <summary>
        /// If you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts, then did you receive a foreign equity distribution that gave rise to a foreign income tax deduction?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 130)]
        public bool? IncomeForeignEquityDistributionForeignTaxDeductionI { get; set; }

        /// <summary>
        /// Amount that is not non-assessable non-exempt under section 768-7
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 131)]
        public decimal? IncomeForeignDeductionNotNonAssessableNonExemptA { get; set; }

        /// <summary>
        /// If you have foreign branch operations or any direct or indirect interests in foreign companies or foreign trusts, then did you derive branch hybrid mismatch income?
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 132)]
        public bool? IncomeDerivedBranchHybridMismatchIncomeI { get; set; }

        /// <summary>
        /// Amounts that are not non-assessable non-exempt under subsection 23AH(4A)
        /// </summary>
        [DataMember(EmitDefaultValue = false, Order = 133)]
        public decimal? IncomeForeignHybridIncomeNotNonAssessableNonExemptA { get; set; }
    }
}
 
