using System;
using System.IO;
using System.Runtime.CompilerServices;
using System.Text;
using System.Xml;
using System.Linq;
using System.Collections.Generic;
using Ato.EN.IntegrationServices.Document.DataContracts;
using System.Text.RegularExpressions;

namespace Ato.EN.IntegrationServices.CodeGenerationLSSCRRYBCK
{

    public partial class LSSCRRYBCK2023Validator
    {
        /// <summary>
        /// The max parameter name length is restricted by the SBR1 and SBR2 schemas - the lowest common denominator of SBR 1 is used as the default
        /// </summary>
        private int _maxParameterNameLength;

        /// <summary>
        /// The max parameter value length is restricted by the SBR1 and SBR2 schemas
        /// </summary>
        private int _maxParameterValueLength;

        /// <summary>
        /// The SBR1 and ebms3 schemas do not allow parameter names or values to be the empty string
        /// </summary>
        private string _emptyParameterValue;

        /// <summary>
        /// The report parameter
        /// </summary>
        private LSSCRRYBCK2023 report;

        /// <summary>
        /// The response parameter
        /// </summary>
        public List<ProcessMessageDocument> response {get; private set;}

        /// <summary>
        /// Initializes a new instance of the <see cref="LSSCRRYBCK2023Validator" /> class.
        /// </summary>
        /// <param name="maxParameterNameLength">Maximum length of the parameter name.</param>
        /// <param name="maxParameterValueLength">Maximum length of the parameter value.</param>
        /// <param name="emptyParameterValue">This value will be used in place of any parameter values that result in a null or empty value.</param>
        public LSSCRRYBCK2023Validator(int maxParameterNameLength = 20, int maxParameterValueLength = 4096, string emptyParameterValue = "EMPTY")
        {
            _maxParameterNameLength = maxParameterNameLength;
            _maxParameterValueLength = maxParameterValueLength;
            _emptyParameterValue = emptyParameterValue;
            this.response = new List<ProcessMessageDocument>();
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="LSSCRRYBCK2023Validator" /> class.
        /// </summary>
        /// <param name="report">Report variable </param>                
        /// <param name="maxParameterNameLength">Maximum length of the parameter name.</param>
        /// <param name="maxParameterValueLength">Maximum length of the parameter value.</param>
        /// <param name="emptyParameterValue">This value will be used in place of any parameter values that result in a null or empty value.</param>
        public LSSCRRYBCK2023Validator(LSSCRRYBCK2023 reportIn, int maxParameterNameLength = 20, int maxParameterValueLength = 4096, string emptyParameterValue = "EMPTY"):this(maxParameterNameLength,maxParameterValueLength,emptyParameterValue)
        {                   
            this.ConsumedReport = reportIn;                    
        }

        #region Functions
        private static IEnumerable<string> Union(IEnumerable<string> list1, IEnumerable<string> list2)
        {
            IEnumerable<string> response;

            if (list1 == null && list2 == null)
            {
                response = null;
            }
            else if (list1 == null)
            {
                response = list2.Distinct();
            }
            else if (list2 == null)
            {
                response = list1.Distinct();
            }
            else
            {
                response = list1.Union(list2);
            }

            return response;
        }

        private static bool IsMatch(int? field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(Convert.ToString(field.Value), expression, options);
        }

        private static bool IsMatch(string field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(field, expression, options);
        }

        // This is just context and tuple counts where they are integer values - easier that changing the parsing logic to just return the value
        private static int Count(int count)
        {
            return count;
        }


        private static int Count<T>(IEnumerable<T> values)
        {
            return values == null ? 0 : values.Where(f => f != null).Count();
        }


        private static int Count<T>(ICollection<T> values)
        {
            return values == null ? 0 : values.Where(f => f != null).Count();
        }

        private static bool exists(bool value)
        {
            return value;
        }

        private static string GetValueOrEmpty(bool? val)
        {
            return (val.HasValue) ? val.ToString().ToLower() : string.Empty;
        }

        private static string GetValueOrEmptyDate(DateTime? val)
        {
            return (val.HasValue) ? val.Value.ToString("yyyy-MM-dd") : string.Empty;
        }

        private static string GetValueOrEmptyDate(string val)
        {
            DateTime dateTimeOut;
            if (DateTime.TryParse(val, out dateTimeOut))
            {
                return dateTimeOut.ToString("yyyy-MM-dd");
            }
            return !string.IsNullOrWhiteSpace(val) ? val : string.Empty;
        }

        private static string GetValueOrEmptyDateTime(string val)
        {
            DateTime dateTimeOut;
            if (DateTime.TryParse(val, out dateTimeOut))
            {
                return dateTimeOut.ToString("yyyy-MM-ddTHH:mm:ssZ");
            }
            return !string.IsNullOrWhiteSpace(val) ? val : string.Empty;
        }

        private static string GetValueOrEmptyDateTime(DateTime? val)
        {
            return (val.HasValue) ? val.Value.ToString("yyyy-MM-ddTHH:mm:ssZ") : string.Empty;
        }

        private static string GetValueOrEmpty(string val)
        {
            return !string.IsNullOrWhiteSpace(val) ? val : string.Empty;
        }

        private static string GetValueOrEmpty(decimal? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        private static string GetValueOrEmpty(int? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

         /// <summary>
         /// Get string value between [first] a and [last] b.
         /// </summary>
        public static string Between(string value, string a, string b)
        {
            int posA = value.IndexOf(a);
            int posB = value.LastIndexOf(b);
            if (posA == -1)
            {
                return "";
            }
            if (posB == -1)
            {
                return "";
            }
            int adjustedPosA = posA + a.Length;
            if (adjustedPosA >= posB)
            {
                return "";
            }
            return value.Substring(adjustedPosA, posB - adjustedPosA);
        }

         /// <summary>
         /// Get string value after [first] a.
         /// </summary>
        public static string Before(string value, string a)
        {
            int posA = value.IndexOf(a);
            if (posA == -1)
            {
                return "";
            }
            return value.Substring(0, posA);
        }

         /// <summary>
         /// Get string value after [last] a.
         /// </summary>
        public static string After(string value, string a)
        {
            int posA = value.LastIndexOf(a);
            if (posA == -1)
            {
                return "";
            }
            int adjustedPosA = posA + a.Length;
            if (adjustedPosA >= value.Length)
            {
                return "";
            }
            return value.Substring(adjustedPosA);
        }

        private static int Length(object field)
        {
            if (field == null)
            return 0;
            else
            return field.ToString().Trim().Length;
        }

        private static bool NotSameValues(IEnumerable<object> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return NotSameValues(nodesArray);
        }

        private static bool NotSameValues(params object[] nodes)
        {
            if (nodes == null)
                return false;

            return (from x in nodes select x).Distinct().Count() != 1;
        }

        private static bool HasDuplicateValues(IEnumerable<DateTime> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return HasDuplicateValues(nodesArray);
        }

        private static bool HasDuplicateValues(IEnumerable<DateTime?> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return HasDuplicateValues(nodesArray);
        }

        private static bool NotSameValues(IEnumerable<DateTime> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return NotSameValues(nodesArray);
        }

        private static bool NotSameValues(IEnumerable<DateTime?> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return NotSameValues(nodesArray);
        }

        private static bool HasDuplicateValues(IEnumerable<object> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return HasDuplicateValues(nodesArray);
        }

        private static bool HasDuplicateValues(params object[] nodes)
        {
           if (nodes == null)
                return false;

            nodes = nodes.Where(x => x != null).ToArray();
            return !((from x in nodes select x).Distinct().Count() == nodes.Count());
        
        }

        private int DuplicateValueIndex(IEnumerable<object> values)
        {
            int response = 0;
            var hashset = new HashSet<object>();
            foreach (var value in values)
            {
                if (!hashset.Add(value))
                {
                    return response;
                }
                response++;
            }
            return response;
        }

        private int DuplicateValueIndex<T>(IEnumerable<T?> values) where T : struct
        {
            int response = 0;
            var hashset = new HashSet<T?>();
            foreach (var value in values)
            {
                if (!hashset.Add(value))
                {
                    return response;
                }
                response++;
            }
            return response;
        }

        private static bool IsDate(object value)
        {
            DateTime dateValue;
            return (value != null && DateTime.TryParse(value.ToString(), out dateValue));
        }

        public DateTime AsDate(string dateAsString)
        {
            DateTime response = DateTime.MinValue;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date;
            }

            return response;
        }

        public DateTime Date(DateTime? datetime)
        {                   
            return datetime.GetValueOrDefault().Date;
        }

				//The logic in After function expects "---" for day and "--" for month. 
				//Since hyphen was missing the date always returned null
        public DateTime? ConvertToDate(int day, int month, int year)
        {
					return ConvertToDate(day == 0 ? null : "---" + day.ToString(), month == 0 ? null : "--" + month.ToString(), year == 0 ? null : year.ToString());
        }

        public DateTime? ConvertToDate(string day, string month, string year)
        {
            DateTime? response;
            DateTime result;

            if (year == null || month == null || day == null)
            {
                return null;
            }
            string dateAsString = year + "-" + After(month, "--") + "-" + After(day, "---");
            if (DateTime.TryParse(dateAsString, out result))
            {
                response = result;
            }
            else
            {
                response = null;
            }
            return response;
        }


        public DateTime? ConvertToDate(string day, string month, int year)
        {
            DateTime? response;
            DateTime result;

            if (year == 0 || month == null || day == null)
            {
                return null;
            }
            string dateAsString = year.ToString() + "-" + After(month, "--") + "-" + After(day, "---");
            if (DateTime.TryParse(dateAsString, out result))
            {
                response = result;
            }
            else
            {
                response = null;
            }
            return response;
        }


        private static int Day(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Day;
            }

            return response;
        }


        private static int Day(DateTime? date)
        {
            if (date == null)
                return 0;
            else
                return date.Value.Day;

        }


        private static string Month(string dateAsString)
        {
            string response = null;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.ToString("MMMM");
            }
            else
            {
                return "NotAMonth";
            }

            return response;
        }

        private static string Month(DateTime? date)
        {
            if (date == null)
                return "NotAMonth";
            else
                return date.Value.ToString("MMMM");
        }


        private static int MonthAsInt(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Month;
            }

            return response;
        }

        private static int MonthAsInt(DateTime? date)
        {
            if (date == null)
            {
                return 0;
            }
            return date.Value.Month;
        }


        private static int Year(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Year;
            }

            return response;
        }

        private static int Year(DateTime? date)
        {
            if (date == null)
                return 0;
            else
                return date.Value.Year;
        }


        private static int CurrentFinancialYear()
        {
            return DateToFinancialYear(DateTime.Now, 7);
        }

        private static int FinancialYear(string dateAsString)
        {
            return DateToFinancialYear(dateAsString, 7);
        }

        private static int FinancialYear(DateTime? date)
        {
            return DateToFinancialYear(date, 7);
        }

        private static int DateToFinancialYear(string dateAsString, int startingMonth)
        {
            int response = 0;
            DateTime date;
            if (DateTime.TryParse(dateAsString, out date))
            {
                response = DateToFinancialYear(date, startingMonth);
            }

            return response;
        }
        private static int DateToFinancialYear(DateTime? date, int startingMonth)
        {
            int response;
            if (date == null)
            {
                response = 0;
            }
            else
            {
                int year = date.Value.Year;
                int month = date.Value.Month;

                if (startingMonth > month)
                    response = year;
                else
                    response = year + 1;
            }
            return response;
        }


        private static int FBTYear(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
                response = FBTYear(date);
            return response;
        }

        private static int FBTYear(DateTime? date)
        {
            if (date == null)
            {
                return 0;
            }
            else
            {
                if (date.Value.Month > 3)
                    return date.Value.Year + 1;
                else
                    return date.Value.Year;
            }
        }

        private static DateTime? AddMonthsToDate(DateTime? dateTime, int months)
        {
            return dateTime == null ? null : (DateTime?)dateTime.Value.AddMonths(months);
        }

        private static bool IsNumeric(object value)
        {
            decimal numbervalue;
            return (value != null && decimal.TryParse(value.ToString(), out numbervalue));
        }

        private static bool NotMonetary(decimal? field, string sign, int digits, int decimals)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;
                string decimalExpression;
                int digitsToUse = digits - decimals;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                if (decimals > 0)
                    decimalExpression = @"(\.\d{1," + decimals + "})?$";
                else
                    decimalExpression = @"$";

                return !(Regex.IsMatch(field.Value.ToString("0.#########################"), signExpression + @"\d{1," + digitsToUse + "}" + decimalExpression));
            }
        }

        private static bool NotNumeric(decimal? field, string sign, int digits, int decimals)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;
                string decimalExpression;
                int digitsToUse = digits - decimals;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                if (decimals > 0)
                    decimalExpression = @"(\.\d{1," + decimals + "})?$";
                else
                    decimalExpression = @"$";

                return !(Regex.IsMatch(field.Value.ToString("0.#########################"), signExpression + @"\d{1," + digitsToUse + "}" + decimalExpression));
            }
        }

        private static bool NotNumeric(int? field, string sign, int digits, int decimals = 0)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                return !(Regex.IsMatch(field.Value.ToString(), signExpression + @"\d{1," + digits + "}$"));
            }
        }

        private static bool NotNumeric(long? field, string sign, int digits, int decimals = 0)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                return !(Regex.IsMatch(field.Value.ToString(), signExpression + @"\d{1," + digits + "}$"));
            }
        }


        private static bool OutsideRange(decimal field, decimal expression, int range)
        {
            bool response;

            response = (field < (expression - range)) || (field > (expression + range));

            return response;
        }


        private static bool FailsUSIAlgorithm(string usi, string abn)
        {
            bool response = true;
            if (usi == null || abn == null)
            {
                response = false;
            }
            else
            {
                usi = usi.Trim();
                abn = abn.Trim();
                if (usi.Length == 14)
                {
                    int numeric;
                    if (usi.Substring(0, 11) == abn && int.TryParse(usi.Substring(11, 3), out numeric))
                        response = false;

                }
                else if (usi.Length == 9)
                {

                    if (Regex.IsMatch(usi, @"^([a-zA-Z]{3}\d{4}[a-zA-Z]{2})$"))
                        response = false;
                }
            }
            return response;
        }

        private static bool FailsTANAlgorithm(string tan)
        {
            bool response;
            decimal decimalTan;

            if (tan == null)
                return false;

            tan = tan.Trim();

            if (!decimal.TryParse(tan, out decimalTan))
                return true;

            if (tan.Length != 8)
                return true;

            decimal tanSum =
                7 * int.Parse(tan.Substring(0, 1)) +
                9 * int.Parse(tan.Substring(1, 1)) +
                8 * int.Parse(tan.Substring(2, 1)) +
                4 * int.Parse(tan.Substring(3, 1)) +
                6 * int.Parse(tan.Substring(4, 1)) +
                3 * int.Parse(tan.Substring(5, 1)) +
                5 * int.Parse(tan.Substring(6, 1)) +
                1 * int.Parse(tan.Substring(7, 1));

            if ((tanSum % 11) == 0)
                response = false;
            else
                response = true;

            return response;
        }


        private static bool FailsABNAlgorithm(string abn)
        {
            bool response;
            decimal decimalAbn;

            if (abn == null)
                return false;

            abn = abn.Trim();

            if (!decimal.TryParse(abn, out decimalAbn))
                return true;

            if (abn.Length != 11)
                return true;

            decimal abnSum =
                10 * (int.Parse(abn.Substring(0, 1)) - 1) +
                1 * int.Parse(abn.Substring(1, 1)) +
                3 * int.Parse(abn.Substring(2, 1)) +
                5 * int.Parse(abn.Substring(3, 1)) +
                7 * int.Parse(abn.Substring(4, 1)) +
                9 * int.Parse(abn.Substring(5, 1)) +
                11 * int.Parse(abn.Substring(6, 1)) +
                13 * int.Parse(abn.Substring(7, 1)) +
                15 * int.Parse(abn.Substring(8, 1)) +
                17 * int.Parse(abn.Substring(9, 1)) +
                19 * int.Parse(abn.Substring(10, 1));

            if ((abnSum % 89) == 0)
                response = false;
            else
                response = true;

            return response;
        }
        private static bool FailsACNAlgorithm(string acn)
        {
            bool response;
            decimal decimalAbn;
            if (acn == null)
                return false;

            acn = acn.Trim();

            if (!decimal.TryParse(acn, out decimalAbn))
                return true;

            if (acn.Length != 9)
                return true;

            decimal abnSum =
                8 * int.Parse(acn.Substring(0, 1)) +
                7 * int.Parse(acn.Substring(1, 1)) +
                6 * int.Parse(acn.Substring(2, 1)) +
                5 * int.Parse(acn.Substring(3, 1)) +
                4 * int.Parse(acn.Substring(4, 1)) +
                3 * int.Parse(acn.Substring(5, 1)) +
                2 * int.Parse(acn.Substring(6, 1)) +
                1 * int.Parse(acn.Substring(7, 1));

            decimal checkDigit = int.Parse(acn.Substring(8, 1));
            decimal acnRemainder = abnSum % 10;

            if (((10 - acnRemainder) % 10) == checkDigit)
                response = false;
            else
                response = true;

            return response;
        }


        private static bool FailsTFNAlgorithm(string tfn)
        {
            bool response;
            decimal decimalTfn;

            if (tfn == null)
                return false;

            tfn = tfn.Trim();
            tfn = Regex.Replace(tfn, "^0+", "");

            if (!decimal.TryParse(tfn, out decimalTfn))
                return true;

            if (tfn.Length < 8)
                return true;


            decimal tfn1To7Sum =
                1 * int.Parse(tfn.Substring(0, 1)) +
                4 * int.Parse(tfn.Substring(1, 1)) +
                3 * int.Parse(tfn.Substring(2, 1)) +
                7 * int.Parse(tfn.Substring(3, 1)) +
                5 * int.Parse(tfn.Substring(4, 1)) +
                8 * int.Parse(tfn.Substring(5, 1)) +
                6 * int.Parse(tfn.Substring(6, 1));

            decimal tfn8 = 9 * int.Parse(tfn.Substring(7, 1));

            if (tfn.Length == 8)
            {
                decimal tFNLg8WSum9 = 10 * int.Parse(tfn.Substring(7, 1));
                decimal tFNLg8WSum = tfn1To7Sum + tFNLg8WSum9;

                if ((tFNLg8WSum % 11) == 0)
                    response = false;
                else
                    response = true;
            }
            else if (tfn.Length == 9)
            {
                decimal tfn9 = 10 * int.Parse(tfn.Substring(8, 1));
                decimal tFNLg9WSum = tfn1To7Sum + tfn8 + tfn9;

                if ((tFNLg9WSum % 11) == 0)
                    response = false;
                else
                    response = true;
            }
            else
            {
                response = true;
            }

            return response;
        }


        private static decimal ConditionalValue(bool expression, decimal? trueVal, decimal? falseVal)
        {
             return expression ? trueVal.GetValueOrDefault() : falseVal.GetValueOrDefault();
        }

        private static decimal AsNumeric(string value)
        {
             decimal numberValue;
             decimal.TryParse(value, out numberValue);
             return numberValue;
        }

        private static bool RegexMatch(int? field, string expression, string flags="")
        {
            return IsMatch(field, expression, GetRegexOption(flags));
        }

        private static bool RegexMatch(string field, string expression, string flags="")
        {
            return IsMatch(field, expression, GetRegexOption(flags));
        }

        private static RegexOptions GetRegexOption(string flags)
        {
            RegexOptions options = RegexOptions.None;

            char[] characters = flags.ToCharArray();

            foreach (char character in characters)
            {
                switch (character)
                {
                    case 'i':                        
                        options = options | RegexOptions.IgnoreCase;                       
                        break;
                    case 'm':                        
                        options = options | RegexOptions.Multiline;                       
                        break;
                    case 's':                        
                            options = options | RegexOptions.Singleline;                       
                        break;
                    case 'n':                        
                            options = options | RegexOptions.ExplicitCapture;                       
                        break;
                    case 'x':                       
                            options = options | RegexOptions.IgnorePatternWhitespace;                       
                        break;
                }
            }

            return options;
        }

        private static string Substring(object field, int start, int length)
        {
            return field.ToString().Substring(start, length);
        }
        
        /// <summary>
        /// Returns an occurrence index as [occurrenceIndex] of occurrenceIndex > 0, otherwise the empty string
        /// </summary>
        /// <param name="occurrenceIndex">Index of the occurrence.</param>
        /// <returns>Occurrence in XPath [#] format</returns>
        public string OccurrenceIndex(int occurrenceIndex)
        {
            return occurrenceIndex > 0 ? "[" + occurrenceIndex + "]" : "";
        }

        #endregion // Functions

        public LSSCRRYBCK2023 ConsumedReport { get {return report;} private set {report = value;}}

        private static Dictionary<string, ProcessMessageDocument> _processMessageDocuments = new Dictionary<string,ProcessMessageDocument>();				

        [MethodImpl(MethodImplOptions.AggressiveInlining)]
        public List<ProcessMessageDocument> ValidateReport(LSSCRRYBCK2023 reportIn)
        {
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            bool assertion;

            this.ConsumedReport = reportIn;

            // ------------------------------------------------------------------------------
            // Validations are now done in code.
            // This version supports full validation of a report - for those rules that have successfully parsed and could be generated.
            // Generated Validations include:
            //   - Validation logic in C#.
            //   - Production of errors in EBMS, SBR and SWS format.
            // 
            // The generation at this stage does not support the following - and has to be completed manually (later versions of the generation will do this for you)
            //   - Business Rules that did not parse.  The ESR team will help support you where this happens as an effort is being made to rectify these
            //   - You will get TODO tasks for those that the parser could not cope with
            // ------------------------------------------------------------------------------
                VRATOLSSCRRYBCK000002();
                VRATOLSSCRRYBCK000003();
                VRATOLSSCRRYBCK000004();

            #region Repeating report.ReturnInformation_ChoiceYearCollection  
            if (report.ReturnInformation_ChoiceYearCollection != null)
            {    
                int itemIndex2 = 0;
                foreach (LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear in report.ReturnInformation_ChoiceYearCollection)
                {
                    itemIndex2++;
                        VRATOLSSCRRYBCK000005(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000006(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000007(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000008(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000009(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000010(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000011(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000012(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000013(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000014(choiceYear, itemIndex2);
                        VRATOLSSCRRYBCK000015(choiceYear, itemIndex2);
                    }
                }
        
                #endregion // Foreach loop

            foreach (ProcessMessageDocument currentProcessMessage in response)
            {
                if (currentProcessMessage.Parameters != null)
                {
                    foreach (ProcessMessageParameter currentParameter in currentProcessMessage.Parameters)
                    {
                        if (string.IsNullOrEmpty(currentParameter.Name))
                        {
                            currentParameter.Name = _emptyParameterValue;
                        }

                        if (currentParameter.Name.Length > _maxParameterNameLength)
                        {
                            currentParameter.Name = currentParameter.Name.Substring(0, _maxParameterNameLength - 1);
                        }

                        if (string.IsNullOrEmpty(currentParameter.Value))
                        {
                            currentParameter.Value = _emptyParameterValue;
                        }

                        if (currentParameter.Value.Length > _maxParameterValueLength)
                        {
                            currentParameter.Value = currentParameter.Value.Substring(0, _maxParameterValueLength - 1);
                        }
                    }
                }
            }

            return response;
        }
				
			
    
      #region VR.ATO.LSSCRRYBCK.000002
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000002()
      {
        ProcessMessageDocument processMessage;
        bool assertion;
    
            /*  VR.ATO.LSSCRRYBCK.000002
            Impact year must not have duplicate values
    
            Legacy Rule Format:
            HasDuplicateValues(^LSSCRRYBCK6)

            Technical Business Rule Format:
            HasDuplicateValues(^LSSCRRYBCK6)
    
            Data Elements:
    
            ^LSSCRRYBCK6 = LSSCRRYBCK:ReturnInformation:ChoiceYear:Report.TargetFinancial.Year
            */
            assertion = HasDuplicateValues(report.ReturnInformation_ChoiceYearCollection == null ? null : report.ReturnInformation_ChoiceYearCollection.Select(f => f.LSSCRRYBCK6).Cast<object>().ToArray());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.LSSCRRYBCK.000002", Severity = ProcessMessageSeverity.Error,
                    Description = @"Impact year must not have duplicate values",
                    Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear[" + report.ReturnInformation_ChoiceYearCollection[DuplicateValueIndex(report.ReturnInformation_ChoiceYearCollection.Select(f => f.LSSCRRYBCK6))].OccurrenceIndex + "]/tns:TargetFinancialY",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000002"} },
                };
                response.Add(processMessage);
            }
      }
      #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000003
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000003()
      {
        ProcessMessageDocument processMessage;
        bool assertion;
    
            /*  VR.ATO.LSSCRRYBCK.000003
            There must be an Impact Year with the value '2023'
    
            Legacy Rule Format:
            CountOccurrence(^LSSCRRYBCK6, ^LSSCRRYBCK6 = 2023) < 1

            Technical Business Rule Format:
            CountOccurrence(^LSSCRRYBCK6, ^LSSCRRYBCK6 = 2023) < 1
    
            Data Elements:
    
            ^LSSCRRYBCK6 = LSSCRRYBCK:ReturnInformation:ChoiceYear:Report.TargetFinancial.Year
            */
            assertion = ((report.ReturnInformation_ChoiceYearCollection == null ? 0 : report.ReturnInformation_ChoiceYearCollection.Count(LSSCRRYBCK6Repeat => LSSCRRYBCK6Repeat.LSSCRRYBCK6 == 2023)) < 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.LSSCRRYBCK.020003", Severity = ProcessMessageSeverity.Error,
                    Description = @"There must be an Impact Year with the value '2023'",
                    Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear/tns:TargetFinancialY",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000003"} },
                };
                response.Add(processMessage);
            }
      }
      #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000004
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000004()
      {
        ProcessMessageDocument processMessage;
        bool assertion;
    
            /*  VR.ATO.LSSCRRYBCK.000004
            When Will the change result in another amendment request for years where there is a consequential impact? is true, then a future impact year must be provided
    
            Legacy Rule Format:
            ^LSSCRRYBCK3 = true AND Count(^LSSCRRYBCK6) < 2

            Technical Business Rule Format:
            ^LSSCRRYBCK3 = true AND Count(^LSSCRRYBCK6) < 2
    
            Data Elements:
    
            ^LSSCRRYBCK6 = LSSCRRYBCK:ReturnInformation:ChoiceYear:Report.TargetFinancial.Year
    
            ^LSSCRRYBCK3 = LSSCRRYBCK:ReturnInformation:Tax.AdditionalAmendment.Indicator
            */
            assertion = (report.LSSCRRYBCK3 == true && Count(report.ReturnInformation_ChoiceYearCollection == null ? new List<int?>() : report.ReturnInformation_ChoiceYearCollection.Select(f => f.LSSCRRYBCK6)) < 2);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.LSSCRRYBCK.000004", Severity = ProcessMessageSeverity.Error,
                    Description = @"Future impact year must be provided",
                    LongDescription = @"When Will the change result in another amendment request for years where there is a consequential impact? is true, then a future impact year must be provided",
                    Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear/tns:TargetFinancialY",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000004"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "LSSCRRYBCK3", Value = GetValueOrEmpty(report.LSSCRRYBCK3) });
    
                response.Add(processMessage);
            }
      }
      #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000005
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000005(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000005
                    When the Impact Year is 2023 then Tax Losses Deducted must be provided
    
                    Legacy Rule Format:
                    ^LSSCRRYBCK6 = 2023 AND ^LSSCRRYBCK1003 = NULL
        
                    Technical Business Rule Format:
                    ^LSSCRRYBCK6 = 2023 AND ^LSSCRRYBCK1003 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK1003 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange
            
                    ^LSSCRRYBCK6 = LSSCRRYBCK:ReturnInformation:ChoiceYear:Report.TargetFinancial.Year
                    */
                    assertion = (choiceYear.LSSCRRYBCK6.GetValueOrDefault() == 2023 && choiceYear.ReturnInformation_ChoiceYear_DeductedChangeCollectionExists == false);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.020005", Severity = ProcessMessageSeverity.Error,
                            Description = @"When the Impact Year is 2023 then Tax Losses Deducted must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:DeductedChange",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000005"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK6", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK6) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000006
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000006(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000006
                    Either Tax Losses Deducted or Tax Losses Carried Forward must be provided
    
                    Legacy Rule Format:
                    ^LSSCRRYBCK1003 = NULL AND ^LSSCRRYBCK1006 = NULL
        
                    Technical Business Rule Format:
                    ^LSSCRRYBCK1003 = NULL AND ^LSSCRRYBCK1006 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK1003 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange
            
                    ^LSSCRRYBCK1006 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange
                    */
                    assertion = (choiceYear.ReturnInformation_ChoiceYear_DeductedChangeCollectionExists == false && choiceYear.ReturnInformation_ChoiceYear_CarriedForwardChangeCollectionExists == false);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000006", Severity = ProcessMessageSeverity.Error,
                            Description = @"Either Tax Losses Deducted or Tax Losses Carried Forward must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:DeductedChange",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000006"} },
                        };
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000007
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000007(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000007
                    When Indicate the change in total tax losses deducted from the original disclosure is 'I' or 'D' then Amount of difference and Adjusted Tax losses deducted amount must be provided
    
                    Legacy Rule Format:
                    InSet(^LSSCRRYBCK7, '"I", "D"') AND ^LSSCRRYBCK8 = NULL AND ^LSSCRRYBCK9 = NULL
        
                    Technical Business Rule Format:
                    InSet(^LSSCRRYBCK7, '"I", "D"') AND ^LSSCRRYBCK8 = NULL AND ^LSSCRRYBCK9 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK7 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK8 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange:Tax.AssessmentDifference.Amount
            
                    ^LSSCRRYBCK9 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange:IncomeTax.Deduction.TaxLossesDeducted.Amount
                    */
                    assertion = (IsMatch(choiceYear.LSSCRRYBCK7, @"^(I|D)$") && choiceYear.LSSCRRYBCK8 == null && choiceYear.LSSCRRYBCK9 == null);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000007", Severity = ProcessMessageSeverity.Error,
                            Description = @"Amount of difference and Adjusted Tax losses deducted amount must be provided",
                            LongDescription = @"When Indicate the change in total tax losses deducted from the original disclosure is 'I' or 'D' then Amount of difference and Adjusted Tax losses deducted amount must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:DeductedChange/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000007"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK7", Value = choiceYear.LSSCRRYBCK7 });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK8", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK8) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK9", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK9) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000008
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000008(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000008
                    When Indicate the change in total tax losses deducted from the original disclosure is 'NC' then Amount of difference and Adjusted Tax losses deducted amount must not be provided
    
                    Legacy Rule Format:
                    ^LSSCRRYBCK7 = "NC" AND (^LSSCRRYBCK8 <> NULL OR ^LSSCRRYBCK9 <> NULL)
        
                    Technical Business Rule Format:
                    ^LSSCRRYBCK7 = 'NC' AND (^LSSCRRYBCK8 <> NULL OR ^LSSCRRYBCK9 <> NULL)
            
                    Data Elements:
            
                    ^LSSCRRYBCK7 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK8 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange:Tax.AssessmentDifference.Amount
            
                    ^LSSCRRYBCK9 = LSSCRRYBCK:ReturnInformation:ChoiceYear:DeductedChange:IncomeTax.Deduction.TaxLossesDeducted.Amount
                    */
                    assertion = (choiceYear.LSSCRRYBCK7 == @"NC" && (choiceYear.LSSCRRYBCK8 != null || choiceYear.LSSCRRYBCK9 != null));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000008", Severity = ProcessMessageSeverity.Error,
                            Description = @"Amount of difference and Adjusted Tax losses deducted amount must not be provided",
                            LongDescription = @"When Indicate the change in total tax losses deducted from the original disclosure is 'NC' then Amount of difference and Adjusted Tax losses deducted amount must not be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:DeductedChange/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000008"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK7", Value = choiceYear.LSSCRRYBCK7 });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK8", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK8) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK9", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK9) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000009
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000009(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000009
                    When the Impact Year is 2023 then Tax Losses Carried Forward must be provided
    
                    Legacy Rule Format:
                    ^LSSCRRYBCK6 = 2023 AND ^LSSCRRYBCK1006 = NULL
        
                    Technical Business Rule Format:
                    ^LSSCRRYBCK6 = 2023 AND ^LSSCRRYBCK1006 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK1006 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange
            
                    ^LSSCRRYBCK6 = LSSCRRYBCK:ReturnInformation:ChoiceYear:Report.TargetFinancial.Year
                    */
                    assertion = (choiceYear.LSSCRRYBCK6.GetValueOrDefault() == 2023 && choiceYear.ReturnInformation_ChoiceYear_CarriedForwardChangeCollectionExists == false);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.020009", Severity = ProcessMessageSeverity.Error,
                            Description = @"When the Impact Year is 2023 then Tax Losses Carried Forward must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:CarriedForwardChange",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000009"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK6", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK6) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000010
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000010(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000010
                    When Indicate change in total tax losses carried forward from the original disclosure is 'I' or 'D' then Amount of difference and Adjusted Tax losses carried forward to later income years must be provided
    
                    Legacy Rule Format:
                    InSet(^LSSCRRYBCK16, '"I", "D"') AND ^LSSCRRYBCK17 = NULL AND ^LSSCRRYBCK18 = NULL
        
                    Technical Business Rule Format:
                    InSet(^LSSCRRYBCK16, '"I", "D"') AND ^LSSCRRYBCK17 = NULL AND ^LSSCRRYBCK18 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK16 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK17 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange:Tax.AssessmentDifference.Amount
            
                    ^LSSCRRYBCK18 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange:Tax.Losses.CarriedForward.Total.Amount
                    */
                    assertion = (IsMatch(choiceYear.LSSCRRYBCK16, @"^(I|D)$") && choiceYear.LSSCRRYBCK17 == null && choiceYear.LSSCRRYBCK18 == null);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000010", Severity = ProcessMessageSeverity.Error,
                            Description = @"Amount of difference and Adjusted Tax losses carried forward to later income years must be provided",
                            LongDescription = @"When Indicate change in total tax losses carried forward from the original disclosure is 'I' or 'D' then Amount of difference and Adjusted Tax losses carried forward to later income years must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:CarriedForwardChange/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000010"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK16", Value = choiceYear.LSSCRRYBCK16 });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK17", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK17) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK18", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK18) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000011
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000011(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000011
                    When Indicate change in total tax losses carried forward from the original disclosure is 'NC' then Amount of difference and Adjusted Tax losses carried forward to later income years must not be provided
    
                    Legacy Rule Format:
                    ^LSSCRRYBCK16 = "NC" AND (^LSSCRRYBCK17 <> NULL OR ^LSSCRRYBCK18 <> NULL)
        
                    Technical Business Rule Format:
                    ^LSSCRRYBCK16 = 'NC' AND (^LSSCRRYBCK17 <> NULL OR ^LSSCRRYBCK18 <> NULL)
            
                    Data Elements:
            
                    ^LSSCRRYBCK16 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK17 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange:Tax.AssessmentDifference.Amount
            
                    ^LSSCRRYBCK18 = LSSCRRYBCK:ReturnInformation:ChoiceYear:CarriedForwardChange:Tax.Losses.CarriedForward.Total.Amount
                    */
                    assertion = (choiceYear.LSSCRRYBCK16 == @"NC" && (choiceYear.LSSCRRYBCK17 != null || choiceYear.LSSCRRYBCK18 != null));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000011", Severity = ProcessMessageSeverity.Error,
                            Description = @"Amount of difference and Adjusted Tax losses carried forward to later income years must not be provided",
                            LongDescription = @"When Indicate change in total tax losses carried forward from the original disclosure is 'NC' then Amount of difference and Adjusted Tax losses carried forward to later income years must not be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:CarriedForwardChange/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000011"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK16", Value = choiceYear.LSSCRRYBCK16 });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK17", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK17) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK18", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK18) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000012
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000012(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000012
                    When Indicate the change in other adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice is 'I' or 'D' then Net amount of any adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice must be provided
    
                    Legacy Rule Format:
                    InSet(^LSSCRRYBCK11, '"I", "D"') AND ^LSSCRRYBCK12 = NULL
        
                    Technical Business Rule Format:
                    InSet(^LSSCRRYBCK11, '"I", "D"') AND ^LSSCRRYBCK12 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK11 = LSSCRRYBCK:ReturnInformation:ChoiceYear:OtherAdjustments:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK12 = LSSCRRYBCK:ReturnInformation:ChoiceYear:OtherAdjustments:Tax.AssessmentDifference.Amount
                    */
                    assertion = (IsMatch(choiceYear.LSSCRRYBCK11, @"^(I|D)$") && choiceYear.LSSCRRYBCK12 == null);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000012", Severity = ProcessMessageSeverity.Error,
                            Description = @"Net amount of any adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice must be provided",
                            LongDescription = @"When Indicate the change in other adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice is 'I' or 'D' then Net amount of any adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:OtherAdjustments/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000012"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK11", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK11) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK12", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK12) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000013
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000013(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000013
                    When Indicate the change in other adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice is 'NC' then Net amount of any adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice must not be provided
    
                    Legacy Rule Format:
                    InSet(^LSSCRRYBCK11, 'NC') AND ^LSSCRRYBCK12 <> NULL
        
                    Technical Business Rule Format:
                    InSet(^LSSCRRYBCK11, 'NC') AND ^LSSCRRYBCK12 <> NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK11 = LSSCRRYBCK:ReturnInformation:ChoiceYear:OtherAdjustments:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK12 = LSSCRRYBCK:ReturnInformation:ChoiceYear:OtherAdjustments:Tax.AssessmentDifference.Amount
                    */
                    assertion = (IsMatch(choiceYear.LSSCRRYBCK11, @"^(NC)$") && choiceYear.LSSCRRYBCK12 != null);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000013", Severity = ProcessMessageSeverity.Error,
                            Description = @"Net amount of any adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice must not be provided",
                            LongDescription = @"When Indicate the change in other adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice is 'NC' then Net amount of any adjustments to taxable / net income or loss due to reasons other than changing a loss carry back choice must not be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:OtherAdjustments/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000013"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK11", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK11) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK12", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK12) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000014
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000014(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000014
                    When Indicate the change in taxable / net income or loss from the original disclosure is 'I' or 'D' then Amount of difference and Adjusted Taxable/net income or loss amount must be provided
    
                    Legacy Rule Format:
                    InSet(^LSSCRRYBCK13, '"I", "D"') AND ^LSSCRRYBCK14 = NULL AND ^LSSCRRYBCK15 = NULL
        
                    Technical Business Rule Format:
                    InSet(^LSSCRRYBCK13, '"I", "D"') AND ^LSSCRRYBCK14 = NULL AND ^LSSCRRYBCK15 = NULL
            
                    Data Elements:
            
                    ^LSSCRRYBCK13 = LSSCRRYBCK:ReturnInformation:ChoiceYear:IncomeOrLossChange:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK14 = LSSCRRYBCK:ReturnInformation:ChoiceYear:IncomeOrLossChange:Tax.AssessmentDifference.Amount
            
                    ^LSSCRRYBCK15 = LSSCRRYBCK:ReturnInformation:ChoiceYear:IncomeOrLossChange:Income.Taxable.Amount
                    */
                    assertion = (IsMatch(choiceYear.LSSCRRYBCK13, @"^(I|D)$") && choiceYear.LSSCRRYBCK14 == null && choiceYear.LSSCRRYBCK15 == null);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000014", Severity = ProcessMessageSeverity.Error,
                            Description = @"Amount of difference and Adjusted Taxable/net income or loss amount must be provided",
                            LongDescription = @"When Indicate the change in taxable / net income or loss from the original disclosure is 'I' or 'D' then Amount of difference and Adjusted Taxable/net income or loss amount must be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:IncomeOrLossChange/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000014"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK13", Value = choiceYear.LSSCRRYBCK13 });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK14", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK14) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK15", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK15) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 
    
      #region VR.ATO.LSSCRRYBCK.000015
      [MethodImpl(MethodImplOptions.AggressiveInlining)]
      public virtual void VRATOLSSCRRYBCK000015(LSSCRRYBCK2023.ReturnInformation_ChoiceYear choiceYear, int itemIndex2)
      {
        ProcessMessageDocument processMessage;
        bool assertion;
            
                    /*  VR.ATO.LSSCRRYBCK.000015
                    When Indicate the change in taxable / net income or loss from the original disclosure is 'NC' then Amount of difference and Adjusted Taxable/net income or loss amount must not be provided
    
                    Legacy Rule Format:
                    InSet(^LSSCRRYBCK13, 'NC') AND (^LSSCRRYBCK14 <> NULL OR ^LSSCRRYBCK15 <> NULL)
        
                    Technical Business Rule Format:
                    InSet(^LSSCRRYBCK13, 'NC') AND (^LSSCRRYBCK14 <> NULL OR ^LSSCRRYBCK15 <> NULL)
            
                    Data Elements:
            
                    ^LSSCRRYBCK13 = LSSCRRYBCK:ReturnInformation:ChoiceYear:IncomeOrLossChange:Tax.Losses.CarryBackChangeType.Code
            
                    ^LSSCRRYBCK14 = LSSCRRYBCK:ReturnInformation:ChoiceYear:IncomeOrLossChange:Tax.AssessmentDifference.Amount
            
                    ^LSSCRRYBCK15 = LSSCRRYBCK:ReturnInformation:ChoiceYear:IncomeOrLossChange:Income.Taxable.Amount
                    */
                    assertion = (IsMatch(choiceYear.LSSCRRYBCK13, @"^(NC)$") && (choiceYear.LSSCRRYBCK14 != null || choiceYear.LSSCRRYBCK15 != null));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.LSSCRRYBCK.000015", Severity = ProcessMessageSeverity.Error,
                            Description = @"Amount of difference and Adjusted Taxable/net income or loss amount must not be provided",
                            LongDescription = @"When Indicate the change in taxable / net income or loss from the original disclosure is 'NC' then Amount of difference and Adjusted Taxable/net income or loss amount must not be provided",
                            Location = "/tns:LSSCRRYBCK/tns:ReturnInformation/tns:ChoiceYearCollection/tns:ChoiceYear" + OccurrenceIndex(choiceYear.OccurrenceIndex) + "/tns:IncomeOrLossChange/tns:TaxLossesCarryBackChangeTypeC",
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.LSSCRRYBCK.000015"} },
                        };
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK13", Value = choiceYear.LSSCRRYBCK13 });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK14", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK14) });
            
                        processMessage.Parameters.Add(new ProcessMessageParameter
                            { Name = "LSSCRRYBCK15", Value = GetValueOrEmpty(choiceYear.LSSCRRYBCK15) });
            
                        response.Add(processMessage);
                    }
              }
              #endregion 

    }
} 
