using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using DataContracts;
namespace Ato.EN.IntegrationServices.CodeGenerationRDTIS
{
    public partial class RDTIS2022Validator
    {
        #region Manual Rules - Rules marked for manual coding

        #region VR.ATO.RDTIS.438109

        /*  VR.ATO.RDTIS.438109
                    If Tax rate is provided, then the Tax rate must be one of the following values 30, 30.00, 25, 25.00

                Legacy Rule Format:
                    IF [RDTIS78] <> NULL AND ([RDTIS78] <> SET("30", "30.00", "25", "25.00"))
                       RETURN VALIDATION MESSAGE
                    ENDIF

            Technical Business Rule Format:
                    ^RDTIS78 <> NULL AND (NotInSet(^RDTIS78, '"30", 30, "25", 25'))

        Data Elements:
    
            ^RDTIS78 = RDTIS:RP:TaxRate.Designation.Rate
            */
        public void VRATORDTIS438109(List<ProcessMessageDocument> response, RDTIS2022 reportIn)
        {
            ProcessMessageDocument processMessage;
            bool assertion;

            assertion = (report.RDTIS78 != null && !(IsMatch(report.RDTIS78.GetValueOrDefault().ToString(), @"^(30|30.00|25|25.00)$", RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.RDTIS.438109",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Tax rate must be one of the following values 30, 30.00, 25, 25.00",
                    Location = "/tns:RDTIS/tns:RP/tns:TaxRateDesignationR",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.RDTIS.438109" } },
                };


                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "RDTIS78", Value = GetValueOrEmpty(report.RDTIS78) });

                response.Add(processMessage);
            }
        }
        #endregion // VR.ATO.RDTIS.438109

        #region VR.ATO.RDTIS.438111

        /*  VR.ATO.RDTIS.438111
                    If R&D intensity is provided, then a valid range for R&D intensity is 000.01 - 100.00

                Legacy Rule Format:
                    IF [RDTIS82] <> NULL AND ([RDTIS82] <> SET(0.01 - 100.00))
                       RETURN VALIDATION MESSAGE
                    ENDIF

            Technical Business Rule Format:
                    ^RDTIS82 <> NULL AND (NotInSet(^RDTIS82, '0.01-100.00'))

        Data Elements:
    
            ^RDTIS82 = RDTIS:RP:NonRefundableTaxOffset:Miscellaneous.ResearchAndDevelopmentIntensity.Rate
            */
        public void VRATORDTIS438111(List<ProcessMessageDocument> response, RDTIS2022 reportIn)
        {
            ProcessMessageDocument processMessage;
            bool assertion;

            assertion = (report.RDTIS82 != null && (report.RDTIS82.GetValueOrDefault() < 0.0001M || report.RDTIS82.GetValueOrDefault() > 100.00M));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.RDTIS.438111",
                    Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Valid range for R&D Intensity is 0.01 - 100.00",
                    Location = "/tns:RDTIS/tns:RP/tns:NonRefundableTaxOffset/tns:MiscellaneousResearchAndDevelopmentIntensityR",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() { Name = "RuleIdentifier", Value = "VR.ATO.RDTIS.438111" } },
                };


                processMessage.Parameters.Add(new ProcessMessageParameter
                { Name = "RDTIS82", Value = GetValueOrEmpty(report.RDTIS82) });

                response.Add(processMessage);
            }
        }
        #endregion // VR.ATO.RDTIS.438111

        #endregion 
    }
}